(function(){const w=document.createElement("link").relList;if(w&&w.supports&&w.supports("modulepreload"))return;for(const X of document.querySelectorAll('link[rel="modulepreload"]'))r(X);new MutationObserver(X=>{for(const I of X)if(I.type==="childList")for(const fl of I.addedNodes)fl.tagName==="LINK"&&fl.rel==="modulepreload"&&r(fl)}).observe(document,{childList:!0,subtree:!0});function V(X){const I={};return X.integrity&&(I.integrity=X.integrity),X.referrerPolicy&&(I.referrerPolicy=X.referrerPolicy),X.crossOrigin==="use-credentials"?I.credentials="include":X.crossOrigin==="anonymous"?I.credentials="omit":I.credentials="same-origin",I}function r(X){if(X.ep)return;X.ep=!0;const I=V(X);fetch(X.href,I)}})();var kc={exports:{}},Te={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Qd;function So(){if(Qd)return Te;Qd=1;var A=Symbol.for("react.transitional.element"),w=Symbol.for("react.fragment");function V(r,X,I){var fl=null;if(I!==void 0&&(fl=""+I),X.key!==void 0&&(fl=""+X.key),"key"in X){I={};for(var al in X)al!=="key"&&(I[al]=X[al])}else I=X;return X=I.ref,{$$typeof:A,type:r,key:fl,ref:X!==void 0?X:null,props:I}}return Te.Fragment=w,Te.jsx=V,Te.jsxs=V,Te}var Cd;function bo(){return Cd||(Cd=1,kc.exports=So()),kc.exports}var Sl=bo(),Fc={exports:{}},j={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Zd;function Eo(){if(Zd)return j;Zd=1;var A=Symbol.for("react.transitional.element"),w=Symbol.for("react.portal"),V=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),X=Symbol.for("react.profiler"),I=Symbol.for("react.consumer"),fl=Symbol.for("react.context"),al=Symbol.for("react.forward_ref"),D=Symbol.for("react.suspense"),b=Symbol.for("react.memo"),W=Symbol.for("react.lazy"),el=Symbol.iterator;function q(s){return s===null||typeof s!="object"?null:(s=el&&s[el]||s["@@iterator"],typeof s=="function"?s:null)}var cl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},_l=Object.assign,Il={};function Kl(s,T,p){this.props=s,this.context=T,this.refs=Il,this.updater=p||cl}Kl.prototype.isReactComponent={},Kl.prototype.setState=function(s,T){if(typeof s!="object"&&typeof s!="function"&&s!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,s,T,"setState")},Kl.prototype.forceUpdate=function(s){this.updater.enqueueForceUpdate(this,s,"forceUpdate")};function Dt(){}Dt.prototype=Kl.prototype;function Gl(s,T,p){this.props=s,this.context=T,this.refs=Il,this.updater=p||cl}var ot=Gl.prototype=new Dt;ot.constructor=Gl,_l(ot,Kl.prototype),ot.isPureReactComponent=!0;var Jt=Array.isArray,F={H:null,A:null,T:null,S:null},Cl=Object.prototype.hasOwnProperty;function wt(s,T,p,R,O,K){return p=K.ref,{$$typeof:A,type:s,key:T,ref:p!==void 0?p:null,props:K}}function Wt(s,T){return wt(s.type,T,void 0,void 0,void 0,s.props)}function N(s){return typeof s=="object"&&s!==null&&s.$$typeof===A}function P(s){var T={"=":"=0",":":"=2"};return"$"+s.replace(/[=:]/g,function(p){return T[p]})}var lt=/\/+/g;function Mt(s,T){return typeof s=="object"&&s!==null&&s.key!=null?P(""+s.key):T.toString(36)}function St(){}function Ut(s){switch(s.status){case"fulfilled":return s.value;case"rejected":throw s.reason;default:switch(typeof s.status=="string"?s.then(St,St):(s.status="pending",s.then(function(T){s.status==="pending"&&(s.status="fulfilled",s.value=T)},function(T){s.status==="pending"&&(s.status="rejected",s.reason=T)})),s.status){case"fulfilled":return s.value;case"rejected":throw s.reason}}throw s}function Zl(s,T,p,R,O){var K=typeof s;(K==="undefined"||K==="boolean")&&(s=null);var Q=!1;if(s===null)Q=!0;else switch(K){case"bigint":case"string":case"number":Q=!0;break;case"object":switch(s.$$typeof){case A:case w:Q=!0;break;case W:return Q=s._init,Zl(Q(s._payload),T,p,R,O)}}if(Q)return O=O(s),Q=R===""?"."+Mt(s,0):R,Jt(O)?(p="",Q!=null&&(p=Q.replace(lt,"$&/")+"/"),Zl(O,T,p,"",function(bl){return bl})):O!=null&&(N(O)&&(O=Wt(O,p+(O.key==null||s&&s.key===O.key?"":(""+O.key).replace(lt,"$&/")+"/")+Q)),T.push(O)),1;Q=0;var jl=R===""?".":R+":";if(Jt(s))for(var ll=0;ll<s.length;ll++)R=s[ll],K=jl+Mt(R,ll),Q+=Zl(R,T,p,K,O);else if(ll=q(s),typeof ll=="function")for(s=ll.call(s),ll=0;!(R=s.next()).done;)R=R.value,K=jl+Mt(R,ll++),Q+=Zl(R,T,p,K,O);else if(K==="object"){if(typeof s.then=="function")return Zl(Ut(s),T,p,R,O);throw T=String(s),Error("Objects are not valid as a React child (found: "+(T==="[object Object]"?"object with keys {"+Object.keys(s).join(", ")+"}":T)+"). If you meant to render a collection of children, use an array instead.")}return Q}function z(s,T,p){if(s==null)return s;var R=[],O=0;return Zl(s,R,"","",function(K){return T.call(p,K,O++)}),R}function G(s){if(s._status===-1){var T=s._result;T=T(),T.then(function(p){(s._status===0||s._status===-1)&&(s._status=1,s._result=p)},function(p){(s._status===0||s._status===-1)&&(s._status=2,s._result=p)}),s._status===-1&&(s._status=0,s._result=T)}if(s._status===1)return s._result.default;throw s._result}var Y=typeof reportError=="function"?reportError:function(s){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var T=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof s=="object"&&s!==null&&typeof s.message=="string"?String(s.message):String(s),error:s});if(!window.dispatchEvent(T))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",s);return}console.error(s)};function il(){}return j.Children={map:z,forEach:function(s,T,p){z(s,function(){T.apply(this,arguments)},p)},count:function(s){var T=0;return z(s,function(){T++}),T},toArray:function(s){return z(s,function(T){return T})||[]},only:function(s){if(!N(s))throw Error("React.Children.only expected to receive a single React element child.");return s}},j.Component=Kl,j.Fragment=V,j.Profiler=X,j.PureComponent=Gl,j.StrictMode=r,j.Suspense=D,j.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=F,j.act=function(){throw Error("act(...) is not supported in production builds of React.")},j.cache=function(s){return function(){return s.apply(null,arguments)}},j.cloneElement=function(s,T,p){if(s==null)throw Error("The argument must be a React element, but you passed "+s+".");var R=_l({},s.props),O=s.key,K=void 0;if(T!=null)for(Q in T.ref!==void 0&&(K=void 0),T.key!==void 0&&(O=""+T.key),T)!Cl.call(T,Q)||Q==="key"||Q==="__self"||Q==="__source"||Q==="ref"&&T.ref===void 0||(R[Q]=T[Q]);var Q=arguments.length-2;if(Q===1)R.children=p;else if(1<Q){for(var jl=Array(Q),ll=0;ll<Q;ll++)jl[ll]=arguments[ll+2];R.children=jl}return wt(s.type,O,void 0,void 0,K,R)},j.createContext=function(s){return s={$$typeof:fl,_currentValue:s,_currentValue2:s,_threadCount:0,Provider:null,Consumer:null},s.Provider=s,s.Consumer={$$typeof:I,_context:s},s},j.createElement=function(s,T,p){var R,O={},K=null;if(T!=null)for(R in T.key!==void 0&&(K=""+T.key),T)Cl.call(T,R)&&R!=="key"&&R!=="__self"&&R!=="__source"&&(O[R]=T[R]);var Q=arguments.length-2;if(Q===1)O.children=p;else if(1<Q){for(var jl=Array(Q),ll=0;ll<Q;ll++)jl[ll]=arguments[ll+2];O.children=jl}if(s&&s.defaultProps)for(R in Q=s.defaultProps,Q)O[R]===void 0&&(O[R]=Q[R]);return wt(s,K,void 0,void 0,null,O)},j.createRef=function(){return{current:null}},j.forwardRef=function(s){return{$$typeof:al,render:s}},j.isValidElement=N,j.lazy=function(s){return{$$typeof:W,_payload:{_status:-1,_result:s},_init:G}},j.memo=function(s,T){return{$$typeof:b,type:s,compare:T===void 0?null:T}},j.startTransition=function(s){var T=F.T,p={};F.T=p;try{var R=s(),O=F.S;O!==null&&O(p,R),typeof R=="object"&&R!==null&&typeof R.then=="function"&&R.then(il,Y)}catch(K){Y(K)}finally{F.T=T}},j.unstable_useCacheRefresh=function(){return F.H.useCacheRefresh()},j.use=function(s){return F.H.use(s)},j.useActionState=function(s,T,p){return F.H.useActionState(s,T,p)},j.useCallback=function(s,T){return F.H.useCallback(s,T)},j.useContext=function(s){return F.H.useContext(s)},j.useDebugValue=function(){},j.useDeferredValue=function(s,T){return F.H.useDeferredValue(s,T)},j.useEffect=function(s,T){return F.H.useEffect(s,T)},j.useId=function(){return F.H.useId()},j.useImperativeHandle=function(s,T,p){return F.H.useImperativeHandle(s,T,p)},j.useInsertionEffect=function(s,T){return F.H.useInsertionEffect(s,T)},j.useLayoutEffect=function(s,T){return F.H.useLayoutEffect(s,T)},j.useMemo=function(s,T){return F.H.useMemo(s,T)},j.useOptimistic=function(s,T){return F.H.useOptimistic(s,T)},j.useReducer=function(s,T,p){return F.H.useReducer(s,T,p)},j.useRef=function(s){return F.H.useRef(s)},j.useState=function(s){return F.H.useState(s)},j.useSyncExternalStore=function(s,T,p){return F.H.useSyncExternalStore(s,T,p)},j.useTransition=function(){return F.H.useTransition()},j.version="19.0.0",j}var xd;function ui(){return xd||(xd=1,Fc.exports=Eo()),Fc.exports}var za=ui(),Pc={exports:{}},Ae={},Ic={exports:{}},li={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Vd;function To(){return Vd||(Vd=1,function(A){function w(z,G){var Y=z.length;z.push(G);l:for(;0<Y;){var il=Y-1>>>1,s=z[il];if(0<X(s,G))z[il]=G,z[Y]=s,Y=il;else break l}}function V(z){return z.length===0?null:z[0]}function r(z){if(z.length===0)return null;var G=z[0],Y=z.pop();if(Y!==G){z[0]=Y;l:for(var il=0,s=z.length,T=s>>>1;il<T;){var p=2*(il+1)-1,R=z[p],O=p+1,K=z[O];if(0>X(R,Y))O<s&&0>X(K,R)?(z[il]=K,z[O]=Y,il=O):(z[il]=R,z[p]=Y,il=p);else if(O<s&&0>X(K,Y))z[il]=K,z[O]=Y,il=O;else break l}}return G}function X(z,G){var Y=z.sortIndex-G.sortIndex;return Y!==0?Y:z.id-G.id}if(A.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var I=performance;A.unstable_now=function(){return I.now()}}else{var fl=Date,al=fl.now();A.unstable_now=function(){return fl.now()-al}}var D=[],b=[],W=1,el=null,q=3,cl=!1,_l=!1,Il=!1,Kl=typeof setTimeout=="function"?setTimeout:null,Dt=typeof clearTimeout=="function"?clearTimeout:null,Gl=typeof setImmediate<"u"?setImmediate:null;function ot(z){for(var G=V(b);G!==null;){if(G.callback===null)r(b);else if(G.startTime<=z)r(b),G.sortIndex=G.expirationTime,w(D,G);else break;G=V(b)}}function Jt(z){if(Il=!1,ot(z),!_l)if(V(D)!==null)_l=!0,Ut();else{var G=V(b);G!==null&&Zl(Jt,G.startTime-z)}}var F=!1,Cl=-1,wt=5,Wt=-1;function N(){return!(A.unstable_now()-Wt<wt)}function P(){if(F){var z=A.unstable_now();Wt=z;var G=!0;try{l:{_l=!1,Il&&(Il=!1,Dt(Cl),Cl=-1),cl=!0;var Y=q;try{t:{for(ot(z),el=V(D);el!==null&&!(el.expirationTime>z&&N());){var il=el.callback;if(typeof il=="function"){el.callback=null,q=el.priorityLevel;var s=il(el.expirationTime<=z);if(z=A.unstable_now(),typeof s=="function"){el.callback=s,ot(z),G=!0;break t}el===V(D)&&r(D),ot(z)}else r(D);el=V(D)}if(el!==null)G=!0;else{var T=V(b);T!==null&&Zl(Jt,T.startTime-z),G=!1}}break l}finally{el=null,q=Y,cl=!1}G=void 0}}finally{G?lt():F=!1}}}var lt;if(typeof Gl=="function")lt=function(){Gl(P)};else if(typeof MessageChannel<"u"){var Mt=new MessageChannel,St=Mt.port2;Mt.port1.onmessage=P,lt=function(){St.postMessage(null)}}else lt=function(){Kl(P,0)};function Ut(){F||(F=!0,lt())}function Zl(z,G){Cl=Kl(function(){z(A.unstable_now())},G)}A.unstable_IdlePriority=5,A.unstable_ImmediatePriority=1,A.unstable_LowPriority=4,A.unstable_NormalPriority=3,A.unstable_Profiling=null,A.unstable_UserBlockingPriority=2,A.unstable_cancelCallback=function(z){z.callback=null},A.unstable_continueExecution=function(){_l||cl||(_l=!0,Ut())},A.unstable_forceFrameRate=function(z){0>z||125<z?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):wt=0<z?Math.floor(1e3/z):5},A.unstable_getCurrentPriorityLevel=function(){return q},A.unstable_getFirstCallbackNode=function(){return V(D)},A.unstable_next=function(z){switch(q){case 1:case 2:case 3:var G=3;break;default:G=q}var Y=q;q=G;try{return z()}finally{q=Y}},A.unstable_pauseExecution=function(){},A.unstable_requestPaint=function(){},A.unstable_runWithPriority=function(z,G){switch(z){case 1:case 2:case 3:case 4:case 5:break;default:z=3}var Y=q;q=z;try{return G()}finally{q=Y}},A.unstable_scheduleCallback=function(z,G,Y){var il=A.unstable_now();switch(typeof Y=="object"&&Y!==null?(Y=Y.delay,Y=typeof Y=="number"&&0<Y?il+Y:il):Y=il,z){case 1:var s=-1;break;case 2:s=250;break;case 5:s=1073741823;break;case 4:s=1e4;break;default:s=5e3}return s=Y+s,z={id:W++,callback:G,priorityLevel:z,startTime:Y,expirationTime:s,sortIndex:-1},Y>il?(z.sortIndex=Y,w(b,z),V(D)===null&&z===V(b)&&(Il?(Dt(Cl),Cl=-1):Il=!0,Zl(Jt,Y-il))):(z.sortIndex=s,w(D,z),_l||cl||(_l=!0,Ut())),z},A.unstable_shouldYield=N,A.unstable_wrapCallback=function(z){var G=q;return function(){var Y=q;q=G;try{return z.apply(this,arguments)}finally{q=Y}}}}(li)),li}var Ld;function Ao(){return Ld||(Ld=1,Ic.exports=To()),Ic.exports}var ti={exports:{}},Bl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Kd;function zo(){if(Kd)return Bl;Kd=1;var A=ui();function w(D){var b="https://react.dev/errors/"+D;if(1<arguments.length){b+="?args[]="+encodeURIComponent(arguments[1]);for(var W=2;W<arguments.length;W++)b+="&args[]="+encodeURIComponent(arguments[W])}return"Minified React error #"+D+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function V(){}var r={d:{f:V,r:function(){throw Error(w(522))},D:V,C:V,L:V,m:V,X:V,S:V,M:V},p:0,findDOMNode:null},X=Symbol.for("react.portal");function I(D,b,W){var el=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:X,key:el==null?null:""+el,children:D,containerInfo:b,implementation:W}}var fl=A.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function al(D,b){if(D==="font")return"";if(typeof b=="string")return b==="use-credentials"?b:""}return Bl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,Bl.createPortal=function(D,b){var W=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!b||b.nodeType!==1&&b.nodeType!==9&&b.nodeType!==11)throw Error(w(299));return I(D,b,null,W)},Bl.flushSync=function(D){var b=fl.T,W=r.p;try{if(fl.T=null,r.p=2,D)return D()}finally{fl.T=b,r.p=W,r.d.f()}},Bl.preconnect=function(D,b){typeof D=="string"&&(b?(b=b.crossOrigin,b=typeof b=="string"?b==="use-credentials"?b:"":void 0):b=null,r.d.C(D,b))},Bl.prefetchDNS=function(D){typeof D=="string"&&r.d.D(D)},Bl.preinit=function(D,b){if(typeof D=="string"&&b&&typeof b.as=="string"){var W=b.as,el=al(W,b.crossOrigin),q=typeof b.integrity=="string"?b.integrity:void 0,cl=typeof b.fetchPriority=="string"?b.fetchPriority:void 0;W==="style"?r.d.S(D,typeof b.precedence=="string"?b.precedence:void 0,{crossOrigin:el,integrity:q,fetchPriority:cl}):W==="script"&&r.d.X(D,{crossOrigin:el,integrity:q,fetchPriority:cl,nonce:typeof b.nonce=="string"?b.nonce:void 0})}},Bl.preinitModule=function(D,b){if(typeof D=="string")if(typeof b=="object"&&b!==null){if(b.as==null||b.as==="script"){var W=al(b.as,b.crossOrigin);r.d.M(D,{crossOrigin:W,integrity:typeof b.integrity=="string"?b.integrity:void 0,nonce:typeof b.nonce=="string"?b.nonce:void 0})}}else b==null&&r.d.M(D)},Bl.preload=function(D,b){if(typeof D=="string"&&typeof b=="object"&&b!==null&&typeof b.as=="string"){var W=b.as,el=al(W,b.crossOrigin);r.d.L(D,W,{crossOrigin:el,integrity:typeof b.integrity=="string"?b.integrity:void 0,nonce:typeof b.nonce=="string"?b.nonce:void 0,type:typeof b.type=="string"?b.type:void 0,fetchPriority:typeof b.fetchPriority=="string"?b.fetchPriority:void 0,referrerPolicy:typeof b.referrerPolicy=="string"?b.referrerPolicy:void 0,imageSrcSet:typeof b.imageSrcSet=="string"?b.imageSrcSet:void 0,imageSizes:typeof b.imageSizes=="string"?b.imageSizes:void 0,media:typeof b.media=="string"?b.media:void 0})}},Bl.preloadModule=function(D,b){if(typeof D=="string")if(b){var W=al(b.as,b.crossOrigin);r.d.m(D,{as:typeof b.as=="string"&&b.as!=="script"?b.as:void 0,crossOrigin:W,integrity:typeof b.integrity=="string"?b.integrity:void 0})}else r.d.m(D)},Bl.requestFormReset=function(D){r.d.r(D)},Bl.unstable_batchedUpdates=function(D,b){return D(b)},Bl.useFormState=function(D,b,W){return fl.H.useFormState(D,b,W)},Bl.useFormStatus=function(){return fl.H.useHostTransitionStatus()},Bl.version="19.0.0",Bl}var Jd;function Oo(){if(Jd)return ti.exports;Jd=1;function A(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(A)}catch(w){console.error(w)}}return A(),ti.exports=zo(),ti.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var wd;function _o(){if(wd)return Ae;wd=1;var A=Ao(),w=ui(),V=Oo();function r(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var u=2;u<arguments.length;u++)t+="&args[]="+encodeURIComponent(arguments[u])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function X(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}var I=Symbol.for("react.element"),fl=Symbol.for("react.transitional.element"),al=Symbol.for("react.portal"),D=Symbol.for("react.fragment"),b=Symbol.for("react.strict_mode"),W=Symbol.for("react.profiler"),el=Symbol.for("react.provider"),q=Symbol.for("react.consumer"),cl=Symbol.for("react.context"),_l=Symbol.for("react.forward_ref"),Il=Symbol.for("react.suspense"),Kl=Symbol.for("react.suspense_list"),Dt=Symbol.for("react.memo"),Gl=Symbol.for("react.lazy"),ot=Symbol.for("react.offscreen"),Jt=Symbol.for("react.memo_cache_sentinel"),F=Symbol.iterator;function Cl(l){return l===null||typeof l!="object"?null:(l=F&&l[F]||l["@@iterator"],typeof l=="function"?l:null)}var wt=Symbol.for("react.client.reference");function Wt(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===wt?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case D:return"Fragment";case al:return"Portal";case W:return"Profiler";case b:return"StrictMode";case Il:return"Suspense";case Kl:return"SuspenseList"}if(typeof l=="object")switch(l.$$typeof){case cl:return(l.displayName||"Context")+".Provider";case q:return(l._context.displayName||"Context")+".Consumer";case _l:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case Dt:return t=l.displayName||null,t!==null?t:Wt(l.type)||"Memo";case Gl:t=l._payload,l=l._init;try{return Wt(l(t))}catch{}}return null}var N=w.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,P=Object.assign,lt,Mt;function St(l){if(lt===void 0)try{throw Error()}catch(u){var t=u.stack.trim().match(/\n( *(at )?)/);lt=t&&t[1]||"",Mt=-1<u.stack.indexOf(`
    at`)?" (<anonymous>)":-1<u.stack.indexOf("@")?"@unknown:0:0":""}return`
`+lt+l+Mt}var Ut=!1;function Zl(l,t){if(!l||Ut)return"";Ut=!0;var u=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var E=function(){throw Error()};if(Object.defineProperty(E.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(E,[])}catch(m){var h=m}Reflect.construct(l,[],E)}else{try{E.call()}catch(m){h=m}l.call(E.prototype)}}else{try{throw Error()}catch(m){h=m}(E=l())&&typeof E.catch=="function"&&E.catch(function(){})}}catch(m){if(m&&h&&typeof m.stack=="string")return[m.stack,h.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=a.DetermineComponentFrameRoot(),f=n[0],c=n[1];if(f&&c){var i=f.split(`
`),v=c.split(`
`);for(e=a=0;a<i.length&&!i[a].includes("DetermineComponentFrameRoot");)a++;for(;e<v.length&&!v[e].includes("DetermineComponentFrameRoot");)e++;if(a===i.length||e===v.length)for(a=i.length-1,e=v.length-1;1<=a&&0<=e&&i[a]!==v[e];)e--;for(;1<=a&&0<=e;a--,e--)if(i[a]!==v[e]){if(a!==1||e!==1)do if(a--,e--,0>e||i[a]!==v[e]){var g=`
`+i[a].replace(" at new "," at ");return l.displayName&&g.includes("<anonymous>")&&(g=g.replace("<anonymous>",l.displayName)),g}while(1<=a&&0<=e);break}}}finally{Ut=!1,Error.prepareStackTrace=u}return(u=l?l.displayName||l.name:"")?St(u):""}function z(l){switch(l.tag){case 26:case 27:case 5:return St(l.type);case 16:return St("Lazy");case 13:return St("Suspense");case 19:return St("SuspenseList");case 0:case 15:return l=Zl(l.type,!1),l;case 11:return l=Zl(l.type.render,!1),l;case 1:return l=Zl(l.type,!0),l;default:return""}}function G(l){try{var t="";do t+=z(l),l=l.return;while(l);return t}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}function Y(l){var t=l,u=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,t.flags&4098&&(u=t.return),l=t.return;while(l)}return t.tag===3?u:null}function il(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function s(l){if(Y(l)!==l)throw Error(r(188))}function T(l){var t=l.alternate;if(!t){if(t=Y(l),t===null)throw Error(r(188));return t!==l?null:l}for(var u=l,a=t;;){var e=u.return;if(e===null)break;var n=e.alternate;if(n===null){if(a=e.return,a!==null){u=a;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===u)return s(e),l;if(n===a)return s(e),t;n=n.sibling}throw Error(r(188))}if(u.return!==a.return)u=e,a=n;else{for(var f=!1,c=e.child;c;){if(c===u){f=!0,u=e,a=n;break}if(c===a){f=!0,a=e,u=n;break}c=c.sibling}if(!f){for(c=n.child;c;){if(c===u){f=!0,u=n,a=e;break}if(c===a){f=!0,a=n,u=e;break}c=c.sibling}if(!f)throw Error(r(189))}}if(u.alternate!==a)throw Error(r(190))}if(u.tag!==3)throw Error(r(188));return u.stateNode.current===u?l:t}function p(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=p(l),t!==null)return t;l=l.sibling}return null}var R=Array.isArray,O=V.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,K={pending:!1,data:null,method:null,action:null},Q=[],jl=-1;function ll(l){return{current:l}}function bl(l){0>jl||(l.current=Q[jl],Q[jl]=null,jl--)}function vl(l,t){jl++,Q[jl]=l.current,l.current=t}var bt=ll(null),Oa=ll(null),$t=ll(null),Oe=ll(null);function _e(l,t){switch(vl($t,t),vl(Oa,l),vl(bt,null),l=t.nodeType,l){case 9:case 11:t=(t=t.documentElement)&&(t=t.namespaceURI)?hd(t):0;break;default:if(l=l===8?t.parentNode:t,t=l.tagName,l=l.namespaceURI)l=hd(l),t=rd(l,t);else switch(t){case"svg":t=1;break;case"math":t=2;break;default:t=0}}bl(bt),vl(bt,t)}function Zu(){bl(bt),bl(Oa),bl($t)}function Cn(l){l.memoizedState!==null&&vl(Oe,l);var t=bt.current,u=rd(t,l.type);t!==u&&(vl(Oa,l),vl(bt,u))}function De(l){Oa.current===l&&(bl(bt),bl(Oa)),Oe.current===l&&(bl(Oe),me._currentValue=K)}var Zn=Object.prototype.hasOwnProperty,xn=A.unstable_scheduleCallback,Vn=A.unstable_cancelCallback,$d=A.unstable_shouldYield,kd=A.unstable_requestPaint,Et=A.unstable_now,Fd=A.unstable_getCurrentPriorityLevel,ai=A.unstable_ImmediatePriority,ei=A.unstable_UserBlockingPriority,Me=A.unstable_NormalPriority,Pd=A.unstable_LowPriority,ni=A.unstable_IdlePriority,Id=A.log,lv=A.unstable_setDisableYieldValue,_a=null,Jl=null;function tv(l){if(Jl&&typeof Jl.onCommitFiberRoot=="function")try{Jl.onCommitFiberRoot(_a,l,void 0,(l.current.flags&128)===128)}catch{}}function kt(l){if(typeof Id=="function"&&lv(l),Jl&&typeof Jl.setStrictMode=="function")try{Jl.setStrictMode(_a,l)}catch{}}var wl=Math.clz32?Math.clz32:ev,uv=Math.log,av=Math.LN2;function ev(l){return l>>>=0,l===0?32:31-(uv(l)/av|0)|0}var Ue=128,Re=4194304;function bu(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l&4194176;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function He(l,t){var u=l.pendingLanes;if(u===0)return 0;var a=0,e=l.suspendedLanes,n=l.pingedLanes,f=l.warmLanes;l=l.finishedLanes!==0;var c=u&134217727;return c!==0?(u=c&~e,u!==0?a=bu(u):(n&=c,n!==0?a=bu(n):l||(f=c&~f,f!==0&&(a=bu(f))))):(c=u&~e,c!==0?a=bu(c):n!==0?a=bu(n):l||(f=u&~f,f!==0&&(a=bu(f)))),a===0?0:t!==0&&t!==a&&!(t&e)&&(e=a&-a,f=t&-t,e>=f||e===32&&(f&4194176)!==0)?t:a}function Da(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function nv(l,t){switch(l){case 1:case 2:case 4:case 8:return t+250;case 16:case 32:case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function fi(){var l=Ue;return Ue<<=1,!(Ue&4194176)&&(Ue=128),l}function ci(){var l=Re;return Re<<=1,!(Re&62914560)&&(Re=4194304),l}function Ln(l){for(var t=[],u=0;31>u;u++)t.push(l);return t}function Ma(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function fv(l,t,u,a,e,n){var f=l.pendingLanes;l.pendingLanes=u,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=u,l.entangledLanes&=u,l.errorRecoveryDisabledLanes&=u,l.shellSuspendCounter=0;var c=l.entanglements,i=l.expirationTimes,v=l.hiddenUpdates;for(u=f&~u;0<u;){var g=31-wl(u),E=1<<g;c[g]=0,i[g]=-1;var h=v[g];if(h!==null)for(v[g]=null,g=0;g<h.length;g++){var m=h[g];m!==null&&(m.lane&=-536870913)}u&=~E}a!==0&&ii(l,a,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(f&~t))}function ii(l,t,u){l.pendingLanes|=t,l.suspendedLanes&=~t;var a=31-wl(t);l.entangledLanes|=t,l.entanglements[a]=l.entanglements[a]|1073741824|u&4194218}function si(l,t){var u=l.entangledLanes|=t;for(l=l.entanglements;u;){var a=31-wl(u),e=1<<a;e&t|l[a]&t&&(l[a]|=t),u&=~e}}function di(l){return l&=-l,2<l?8<l?l&134217727?32:268435456:8:2}function vi(){var l=O.p;return l!==0?l:(l=window.event,l===void 0?32:qd(l.type))}function cv(l,t){var u=O.p;try{return O.p=l,t()}finally{O.p=u}}var Ft=Math.random().toString(36).slice(2),ql="__reactFiber$"+Ft,xl="__reactProps$"+Ft,xu="__reactContainer$"+Ft,Kn="__reactEvents$"+Ft,iv="__reactListeners$"+Ft,sv="__reactHandles$"+Ft,yi="__reactResources$"+Ft,Ua="__reactMarker$"+Ft;function Jn(l){delete l[ql],delete l[xl],delete l[Kn],delete l[iv],delete l[sv]}function Eu(l){var t=l[ql];if(t)return t;for(var u=l.parentNode;u;){if(t=u[xu]||u[ql]){if(u=t.alternate,t.child!==null||u!==null&&u.child!==null)for(l=Sd(l);l!==null;){if(u=l[ql])return u;l=Sd(l)}return t}l=u,u=l.parentNode}return null}function Vu(l){if(l=l[ql]||l[xu]){var t=l.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return l}return null}function Ra(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(r(33))}function Lu(l){var t=l[yi];return t||(t=l[yi]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Dl(l){l[Ua]=!0}var oi=new Set,hi={};function Tu(l,t){Ku(l,t),Ku(l+"Capture",t)}function Ku(l,t){for(hi[l]=t,l=0;l<t.length;l++)oi.add(t[l])}var Rt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),dv=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),ri={},mi={};function vv(l){return Zn.call(mi,l)?!0:Zn.call(ri,l)?!1:dv.test(l)?mi[l]=!0:(ri[l]=!0,!1)}function Ne(l,t,u){if(vv(t))if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+u)}}function pe(l,t,u){if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+u)}}function Ht(l,t,u,a){if(a===null)l.removeAttribute(u);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(u);return}l.setAttributeNS(t,u,""+a)}}function tt(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function gi(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function yv(l){var t=gi(l)?"checked":"value",u=Object.getOwnPropertyDescriptor(l.constructor.prototype,t),a=""+l[t];if(!l.hasOwnProperty(t)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var e=u.get,n=u.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(f){a=""+f,n.call(this,f)}}),Object.defineProperty(l,t,{enumerable:u.enumerable}),{getValue:function(){return a},setValue:function(f){a=""+f},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function qe(l){l._valueTracker||(l._valueTracker=yv(l))}function Si(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var u=t.getValue(),a="";return l&&(a=gi(l)?l.checked?"true":"false":l.value),l=a,l!==u?(t.setValue(l),!0):!1}function Ye(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var ov=/[\n"\\]/g;function ut(l){return l.replace(ov,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function wn(l,t,u,a,e,n,f,c){l.name="",f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.type=f:l.removeAttribute("type"),t!=null?f==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+tt(t)):l.value!==""+tt(t)&&(l.value=""+tt(t)):f!=="submit"&&f!=="reset"||l.removeAttribute("value"),t!=null?Wn(l,f,tt(t)):u!=null?Wn(l,f,tt(u)):a!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.name=""+tt(c):l.removeAttribute("name")}function bi(l,t,u,a,e,n,f,c){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||u!=null){if(!(n!=="submit"&&n!=="reset"||t!=null))return;u=u!=null?""+tt(u):"",t=t!=null?""+tt(t):u,c||t===l.value||(l.value=t),l.defaultValue=t}a=a??e,a=typeof a!="function"&&typeof a!="symbol"&&!!a,l.checked=c?l.checked:!!a,l.defaultChecked=!!a,f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"&&(l.name=f)}function Wn(l,t,u){t==="number"&&Ye(l.ownerDocument)===l||l.defaultValue===""+u||(l.defaultValue=""+u)}function Ju(l,t,u,a){if(l=l.options,t){t={};for(var e=0;e<u.length;e++)t["$"+u[e]]=!0;for(u=0;u<l.length;u++)e=t.hasOwnProperty("$"+l[u].value),l[u].selected!==e&&(l[u].selected=e),e&&a&&(l[u].defaultSelected=!0)}else{for(u=""+tt(u),t=null,e=0;e<l.length;e++){if(l[e].value===u){l[e].selected=!0,a&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function Ei(l,t,u){if(t!=null&&(t=""+tt(t),t!==l.value&&(l.value=t),u==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=u!=null?""+tt(u):""}function Ti(l,t,u,a){if(t==null){if(a!=null){if(u!=null)throw Error(r(92));if(R(a)){if(1<a.length)throw Error(r(93));a=a[0]}u=a}u==null&&(u=""),t=u}u=tt(t),l.defaultValue=u,a=l.textContent,a===u&&a!==""&&a!==null&&(l.value=a)}function wu(l,t){if(t){var u=l.firstChild;if(u&&u===l.lastChild&&u.nodeType===3){u.nodeValue=t;return}}l.textContent=t}var hv=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Ai(l,t,u){var a=t.indexOf("--")===0;u==null||typeof u=="boolean"||u===""?a?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":a?l.setProperty(t,u):typeof u!="number"||u===0||hv.has(t)?t==="float"?l.cssFloat=u:l[t]=(""+u).trim():l[t]=u+"px"}function zi(l,t,u){if(t!=null&&typeof t!="object")throw Error(r(62));if(l=l.style,u!=null){for(var a in u)!u.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?l.setProperty(a,""):a==="float"?l.cssFloat="":l[a]="");for(var e in t)a=t[e],t.hasOwnProperty(e)&&u[e]!==a&&Ai(l,e,a)}else for(var n in t)t.hasOwnProperty(n)&&Ai(l,n,t[n])}function $n(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var rv=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),mv=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Be(l){return mv.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}var kn=null;function Fn(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Wu=null,$u=null;function Oi(l){var t=Vu(l);if(t&&(l=t.stateNode)){var u=l[xl]||null;l:switch(l=t.stateNode,t.type){case"input":if(wn(l,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name),t=u.name,u.type==="radio"&&t!=null){for(u=l;u.parentNode;)u=u.parentNode;for(u=u.querySelectorAll('input[name="'+ut(""+t)+'"][type="radio"]'),t=0;t<u.length;t++){var a=u[t];if(a!==l&&a.form===l.form){var e=a[xl]||null;if(!e)throw Error(r(90));wn(a,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<u.length;t++)a=u[t],a.form===l.form&&Si(a)}break l;case"textarea":Ei(l,u.value,u.defaultValue);break l;case"select":t=u.value,t!=null&&Ju(l,!!u.multiple,t,!1)}}}var Pn=!1;function _i(l,t,u){if(Pn)return l(t,u);Pn=!0;try{var a=l(t);return a}finally{if(Pn=!1,(Wu!==null||$u!==null)&&(bn(),Wu&&(t=Wu,l=$u,$u=Wu=null,Oi(t),l)))for(t=0;t<l.length;t++)Oi(l[t])}}function Ha(l,t){var u=l.stateNode;if(u===null)return null;var a=u[xl]||null;if(a===null)return null;u=a[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(l=l.type,a=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!a;break l;default:l=!1}if(l)return null;if(u&&typeof u!="function")throw Error(r(231,t,typeof u));return u}var In=!1;if(Rt)try{var Na={};Object.defineProperty(Na,"passive",{get:function(){In=!0}}),window.addEventListener("test",Na,Na),window.removeEventListener("test",Na,Na)}catch{In=!1}var Pt=null,lf=null,Ge=null;function Di(){if(Ge)return Ge;var l,t=lf,u=t.length,a,e="value"in Pt?Pt.value:Pt.textContent,n=e.length;for(l=0;l<u&&t[l]===e[l];l++);var f=u-l;for(a=1;a<=f&&t[u-a]===e[n-a];a++);return Ge=e.slice(l,1<a?1-a:void 0)}function je(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function Xe(){return!0}function Mi(){return!1}function Vl(l){function t(u,a,e,n,f){this._reactName=u,this._targetInst=e,this.type=a,this.nativeEvent=n,this.target=f,this.currentTarget=null;for(var c in l)l.hasOwnProperty(c)&&(u=l[c],this[c]=u?u(n):n[c]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?Xe:Mi,this.isPropagationStopped=Mi,this}return P(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var u=this.nativeEvent;u&&(u.preventDefault?u.preventDefault():typeof u.returnValue!="unknown"&&(u.returnValue=!1),this.isDefaultPrevented=Xe)},stopPropagation:function(){var u=this.nativeEvent;u&&(u.stopPropagation?u.stopPropagation():typeof u.cancelBubble!="unknown"&&(u.cancelBubble=!0),this.isPropagationStopped=Xe)},persist:function(){},isPersistent:Xe}),t}var Au={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Qe=Vl(Au),pa=P({},Au,{view:0,detail:0}),gv=Vl(pa),tf,uf,qa,Ce=P({},pa,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:ef,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==qa&&(qa&&l.type==="mousemove"?(tf=l.screenX-qa.screenX,uf=l.screenY-qa.screenY):uf=tf=0,qa=l),tf)},movementY:function(l){return"movementY"in l?l.movementY:uf}}),Ui=Vl(Ce),Sv=P({},Ce,{dataTransfer:0}),bv=Vl(Sv),Ev=P({},pa,{relatedTarget:0}),af=Vl(Ev),Tv=P({},Au,{animationName:0,elapsedTime:0,pseudoElement:0}),Av=Vl(Tv),zv=P({},Au,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),Ov=Vl(zv),_v=P({},Au,{data:0}),Ri=Vl(_v),Dv={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Mv={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Uv={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Rv(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=Uv[l])?!!t[l]:!1}function ef(){return Rv}var Hv=P({},pa,{key:function(l){if(l.key){var t=Dv[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=je(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?Mv[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:ef,charCode:function(l){return l.type==="keypress"?je(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?je(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),Nv=Vl(Hv),pv=P({},Ce,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Hi=Vl(pv),qv=P({},pa,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:ef}),Yv=Vl(qv),Bv=P({},Au,{propertyName:0,elapsedTime:0,pseudoElement:0}),Gv=Vl(Bv),jv=P({},Ce,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),Xv=Vl(jv),Qv=P({},Au,{newState:0,oldState:0}),Cv=Vl(Qv),Zv=[9,13,27,32],nf=Rt&&"CompositionEvent"in window,Ya=null;Rt&&"documentMode"in document&&(Ya=document.documentMode);var xv=Rt&&"TextEvent"in window&&!Ya,Ni=Rt&&(!nf||Ya&&8<Ya&&11>=Ya),pi=" ",qi=!1;function Yi(l,t){switch(l){case"keyup":return Zv.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Bi(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var ku=!1;function Vv(l,t){switch(l){case"compositionend":return Bi(t);case"keypress":return t.which!==32?null:(qi=!0,pi);case"textInput":return l=t.data,l===pi&&qi?null:l;default:return null}}function Lv(l,t){if(ku)return l==="compositionend"||!nf&&Yi(l,t)?(l=Di(),Ge=lf=Pt=null,ku=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Ni&&t.locale!=="ko"?null:t.data;default:return null}}var Kv={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Gi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!Kv[l.type]:t==="textarea"}function ji(l,t,u,a){Wu?$u?$u.push(a):$u=[a]:Wu=a,t=On(t,"onChange"),0<t.length&&(u=new Qe("onChange","change",null,u,a),l.push({event:u,listeners:t}))}var Ba=null,Ga=null;function Jv(l){sd(l,0)}function Ze(l){var t=Ra(l);if(Si(t))return l}function Xi(l,t){if(l==="change")return t}var Qi=!1;if(Rt){var ff;if(Rt){var cf="oninput"in document;if(!cf){var Ci=document.createElement("div");Ci.setAttribute("oninput","return;"),cf=typeof Ci.oninput=="function"}ff=cf}else ff=!1;Qi=ff&&(!document.documentMode||9<document.documentMode)}function Zi(){Ba&&(Ba.detachEvent("onpropertychange",xi),Ga=Ba=null)}function xi(l){if(l.propertyName==="value"&&Ze(Ga)){var t=[];ji(t,Ga,l,Fn(l)),_i(Jv,t)}}function wv(l,t,u){l==="focusin"?(Zi(),Ba=t,Ga=u,Ba.attachEvent("onpropertychange",xi)):l==="focusout"&&Zi()}function Wv(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ze(Ga)}function $v(l,t){if(l==="click")return Ze(t)}function kv(l,t){if(l==="input"||l==="change")return Ze(t)}function Fv(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var Wl=typeof Object.is=="function"?Object.is:Fv;function ja(l,t){if(Wl(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var u=Object.keys(l),a=Object.keys(t);if(u.length!==a.length)return!1;for(a=0;a<u.length;a++){var e=u[a];if(!Zn.call(t,e)||!Wl(l[e],t[e]))return!1}return!0}function Vi(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function Li(l,t){var u=Vi(l);l=0;for(var a;u;){if(u.nodeType===3){if(a=l+u.textContent.length,l<=t&&a>=t)return{node:u,offset:t-l};l=a}l:{for(;u;){if(u.nextSibling){u=u.nextSibling;break l}u=u.parentNode}u=void 0}u=Vi(u)}}function Ki(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?Ki(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function Ji(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Ye(l.document);t instanceof l.HTMLIFrameElement;){try{var u=typeof t.contentWindow.location.href=="string"}catch{u=!1}if(u)l=t.contentWindow;else break;t=Ye(l.document)}return t}function sf(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}function Pv(l,t){var u=Ji(t);t=l.focusedElem;var a=l.selectionRange;if(u!==t&&t&&t.ownerDocument&&Ki(t.ownerDocument.documentElement,t)){if(a!==null&&sf(t)){if(l=a.start,u=a.end,u===void 0&&(u=l),"selectionStart"in t)t.selectionStart=l,t.selectionEnd=Math.min(u,t.value.length);else if(u=(l=t.ownerDocument||document)&&l.defaultView||window,u.getSelection){u=u.getSelection();var e=t.textContent.length,n=Math.min(a.start,e);a=a.end===void 0?n:Math.min(a.end,e),!u.extend&&n>a&&(e=a,a=n,n=e),e=Li(t,n);var f=Li(t,a);e&&f&&(u.rangeCount!==1||u.anchorNode!==e.node||u.anchorOffset!==e.offset||u.focusNode!==f.node||u.focusOffset!==f.offset)&&(l=l.createRange(),l.setStart(e.node,e.offset),u.removeAllRanges(),n>a?(u.addRange(l),u.extend(f.node,f.offset)):(l.setEnd(f.node,f.offset),u.addRange(l)))}}for(l=[],u=t;u=u.parentNode;)u.nodeType===1&&l.push({element:u,left:u.scrollLeft,top:u.scrollTop});for(typeof t.focus=="function"&&t.focus(),t=0;t<l.length;t++)u=l[t],u.element.scrollLeft=u.left,u.element.scrollTop=u.top}}var Iv=Rt&&"documentMode"in document&&11>=document.documentMode,Fu=null,df=null,Xa=null,vf=!1;function wi(l,t,u){var a=u.window===u?u.document:u.nodeType===9?u:u.ownerDocument;vf||Fu==null||Fu!==Ye(a)||(a=Fu,"selectionStart"in a&&sf(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Xa&&ja(Xa,a)||(Xa=a,a=On(df,"onSelect"),0<a.length&&(t=new Qe("onSelect","select",null,t,u),l.push({event:t,listeners:a}),t.target=Fu)))}function zu(l,t){var u={};return u[l.toLowerCase()]=t.toLowerCase(),u["Webkit"+l]="webkit"+t,u["Moz"+l]="moz"+t,u}var Pu={animationend:zu("Animation","AnimationEnd"),animationiteration:zu("Animation","AnimationIteration"),animationstart:zu("Animation","AnimationStart"),transitionrun:zu("Transition","TransitionRun"),transitionstart:zu("Transition","TransitionStart"),transitioncancel:zu("Transition","TransitionCancel"),transitionend:zu("Transition","TransitionEnd")},yf={},Wi={};Rt&&(Wi=document.createElement("div").style,"AnimationEvent"in window||(delete Pu.animationend.animation,delete Pu.animationiteration.animation,delete Pu.animationstart.animation),"TransitionEvent"in window||delete Pu.transitionend.transition);function Ou(l){if(yf[l])return yf[l];if(!Pu[l])return l;var t=Pu[l],u;for(u in t)if(t.hasOwnProperty(u)&&u in Wi)return yf[l]=t[u];return l}var $i=Ou("animationend"),ki=Ou("animationiteration"),Fi=Ou("animationstart"),ly=Ou("transitionrun"),ty=Ou("transitionstart"),uy=Ou("transitioncancel"),Pi=Ou("transitionend"),Ii=new Map,ls="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll scrollEnd toggle touchMove waiting wheel".split(" ");function ht(l,t){Ii.set(l,t),Tu(t,[l])}var at=[],Iu=0,of=0;function xe(){for(var l=Iu,t=of=Iu=0;t<l;){var u=at[t];at[t++]=null;var a=at[t];at[t++]=null;var e=at[t];at[t++]=null;var n=at[t];if(at[t++]=null,a!==null&&e!==null){var f=a.pending;f===null?e.next=e:(e.next=f.next,f.next=e),a.pending=e}n!==0&&ts(u,e,n)}}function Ve(l,t,u,a){at[Iu++]=l,at[Iu++]=t,at[Iu++]=u,at[Iu++]=a,of|=a,l.lanes|=a,l=l.alternate,l!==null&&(l.lanes|=a)}function hf(l,t,u,a){return Ve(l,t,u,a),Le(l)}function It(l,t){return Ve(l,null,null,t),Le(l)}function ts(l,t,u){l.lanes|=u;var a=l.alternate;a!==null&&(a.lanes|=u);for(var e=!1,n=l.return;n!==null;)n.childLanes|=u,a=n.alternate,a!==null&&(a.childLanes|=u),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;e&&t!==null&&l.tag===3&&(n=l.stateNode,e=31-wl(u),n=n.hiddenUpdates,l=n[e],l===null?n[e]=[t]:l.push(t),t.lane=u|536870912)}function Le(l){if(50<se)throw se=0,Ec=null,Error(r(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var la={},us=new WeakMap;function et(l,t){if(typeof l=="object"&&l!==null){var u=us.get(l);return u!==void 0?u:(t={value:l,source:t,stack:G(t)},us.set(l,t),t)}return{value:l,source:t,stack:G(t)}}var ta=[],ua=0,Ke=null,Je=0,nt=[],ft=0,_u=null,Nt=1,pt="";function Du(l,t){ta[ua++]=Je,ta[ua++]=Ke,Ke=l,Je=t}function as(l,t,u){nt[ft++]=Nt,nt[ft++]=pt,nt[ft++]=_u,_u=l;var a=Nt;l=pt;var e=32-wl(a)-1;a&=~(1<<e),u+=1;var n=32-wl(t)+e;if(30<n){var f=e-e%5;n=(a&(1<<f)-1).toString(32),a>>=f,e-=f,Nt=1<<32-wl(t)+e|u<<e|a,pt=n+l}else Nt=1<<n|u<<e|a,pt=l}function rf(l){l.return!==null&&(Du(l,1),as(l,1,0))}function mf(l){for(;l===Ke;)Ke=ta[--ua],ta[ua]=null,Je=ta[--ua],ta[ua]=null;for(;l===_u;)_u=nt[--ft],nt[ft]=null,pt=nt[--ft],nt[ft]=null,Nt=nt[--ft],nt[ft]=null}var Xl=null,Hl=null,$=!1,rt=null,Tt=!1,gf=Error(r(519));function Mu(l){var t=Error(r(418,""));throw Za(et(t,l)),gf}function es(l){var t=l.stateNode,u=l.type,a=l.memoizedProps;switch(t[ql]=l,t[xl]=a,u){case"dialog":L("cancel",t),L("close",t);break;case"iframe":case"object":case"embed":L("load",t);break;case"video":case"audio":for(u=0;u<ve.length;u++)L(ve[u],t);break;case"source":L("error",t);break;case"img":case"image":case"link":L("error",t),L("load",t);break;case"details":L("toggle",t);break;case"input":L("invalid",t),bi(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0),qe(t);break;case"select":L("invalid",t);break;case"textarea":L("invalid",t),Ti(t,a.value,a.defaultValue,a.children),qe(t)}u=a.children,typeof u!="string"&&typeof u!="number"&&typeof u!="bigint"||t.textContent===""+u||a.suppressHydrationWarning===!0||od(t.textContent,u)?(a.popover!=null&&(L("beforetoggle",t),L("toggle",t)),a.onScroll!=null&&L("scroll",t),a.onScrollEnd!=null&&L("scrollend",t),a.onClick!=null&&(t.onclick=_n),t=!0):t=!1,t||Mu(l)}function ns(l){for(Xl=l.return;Xl;)switch(Xl.tag){case 3:case 27:Tt=!0;return;case 5:case 13:Tt=!1;return;default:Xl=Xl.return}}function Qa(l){if(l!==Xl)return!1;if(!$)return ns(l),$=!0,!1;var t=!1,u;if((u=l.tag!==3&&l.tag!==27)&&((u=l.tag===5)&&(u=l.type,u=!(u!=="form"&&u!=="button")||jc(l.type,l.memoizedProps)),u=!u),u&&(t=!0),t&&Hl&&Mu(l),ns(l),l.tag===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(r(317));l:{for(l=l.nextSibling,t=0;l;){if(l.nodeType===8)if(u=l.data,u==="/$"){if(t===0){Hl=gt(l.nextSibling);break l}t--}else u!=="$"&&u!=="$!"&&u!=="$?"||t++;l=l.nextSibling}Hl=null}}else Hl=Xl?gt(l.stateNode.nextSibling):null;return!0}function Ca(){Hl=Xl=null,$=!1}function Za(l){rt===null?rt=[l]:rt.push(l)}var xa=Error(r(460)),fs=Error(r(474)),Sf={then:function(){}};function cs(l){return l=l.status,l==="fulfilled"||l==="rejected"}function we(){}function is(l,t,u){switch(u=l[u],u===void 0?l.push(t):u!==t&&(t.then(we,we),t=u),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,l===xa?Error(r(483)):l;default:if(typeof t.status=="string")t.then(we,we);else{if(l=sl,l!==null&&100<l.shellSuspendCounter)throw Error(r(482));l=t,l.status="pending",l.then(function(a){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=a}},function(a){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,l===xa?Error(r(483)):l}throw Va=t,xa}}var Va=null;function ss(){if(Va===null)throw Error(r(459));var l=Va;return Va=null,l}var aa=null,La=0;function We(l){var t=La;return La+=1,aa===null&&(aa=[]),is(aa,l,t)}function Ka(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function $e(l,t){throw t.$$typeof===I?Error(r(525)):(l=Object.prototype.toString.call(t),Error(r(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function ds(l){var t=l._init;return t(l._payload)}function vs(l){function t(y,d){if(l){var o=y.deletions;o===null?(y.deletions=[d],y.flags|=16):o.push(d)}}function u(y,d){if(!l)return null;for(;d!==null;)t(y,d),d=d.sibling;return null}function a(y){for(var d=new Map;y!==null;)y.key!==null?d.set(y.key,y):d.set(y.index,y),y=y.sibling;return d}function e(y,d){return y=vu(y,d),y.index=0,y.sibling=null,y}function n(y,d,o){return y.index=o,l?(o=y.alternate,o!==null?(o=o.index,o<d?(y.flags|=33554434,d):o):(y.flags|=33554434,d)):(y.flags|=1048576,d)}function f(y){return l&&y.alternate===null&&(y.flags|=33554434),y}function c(y,d,o,S){return d===null||d.tag!==6?(d=yc(o,y.mode,S),d.return=y,d):(d=e(d,o),d.return=y,d)}function i(y,d,o,S){var _=o.type;return _===D?g(y,d,o.props.children,S,o.key):d!==null&&(d.elementType===_||typeof _=="object"&&_!==null&&_.$$typeof===Gl&&ds(_)===d.type)?(d=e(d,o.props),Ka(d,o),d.return=y,d):(d=hn(o.type,o.key,o.props,null,y.mode,S),Ka(d,o),d.return=y,d)}function v(y,d,o,S){return d===null||d.tag!==4||d.stateNode.containerInfo!==o.containerInfo||d.stateNode.implementation!==o.implementation?(d=oc(o,y.mode,S),d.return=y,d):(d=e(d,o.children||[]),d.return=y,d)}function g(y,d,o,S,_){return d===null||d.tag!==7?(d=ju(o,y.mode,S,_),d.return=y,d):(d=e(d,o),d.return=y,d)}function E(y,d,o){if(typeof d=="string"&&d!==""||typeof d=="number"||typeof d=="bigint")return d=yc(""+d,y.mode,o),d.return=y,d;if(typeof d=="object"&&d!==null){switch(d.$$typeof){case fl:return o=hn(d.type,d.key,d.props,null,y.mode,o),Ka(o,d),o.return=y,o;case al:return d=oc(d,y.mode,o),d.return=y,d;case Gl:var S=d._init;return d=S(d._payload),E(y,d,o)}if(R(d)||Cl(d))return d=ju(d,y.mode,o,null),d.return=y,d;if(typeof d.then=="function")return E(y,We(d),o);if(d.$$typeof===cl)return E(y,vn(y,d),o);$e(y,d)}return null}function h(y,d,o,S){var _=d!==null?d.key:null;if(typeof o=="string"&&o!==""||typeof o=="number"||typeof o=="bigint")return _!==null?null:c(y,d,""+o,S);if(typeof o=="object"&&o!==null){switch(o.$$typeof){case fl:return o.key===_?i(y,d,o,S):null;case al:return o.key===_?v(y,d,o,S):null;case Gl:return _=o._init,o=_(o._payload),h(y,d,o,S)}if(R(o)||Cl(o))return _!==null?null:g(y,d,o,S,null);if(typeof o.then=="function")return h(y,d,We(o),S);if(o.$$typeof===cl)return h(y,d,vn(y,o),S);$e(y,o)}return null}function m(y,d,o,S,_){if(typeof S=="string"&&S!==""||typeof S=="number"||typeof S=="bigint")return y=y.get(o)||null,c(d,y,""+S,_);if(typeof S=="object"&&S!==null){switch(S.$$typeof){case fl:return y=y.get(S.key===null?o:S.key)||null,i(d,y,S,_);case al:return y=y.get(S.key===null?o:S.key)||null,v(d,y,S,_);case Gl:var Z=S._init;return S=Z(S._payload),m(y,d,o,S,_)}if(R(S)||Cl(S))return y=y.get(o)||null,g(d,y,S,_,null);if(typeof S.then=="function")return m(y,d,o,We(S),_);if(S.$$typeof===cl)return m(y,d,o,vn(d,S),_);$e(d,S)}return null}function M(y,d,o,S){for(var _=null,Z=null,U=d,H=d=0,Rl=null;U!==null&&H<o.length;H++){U.index>H?(Rl=U,U=null):Rl=U.sibling;var k=h(y,U,o[H],S);if(k===null){U===null&&(U=Rl);break}l&&U&&k.alternate===null&&t(y,U),d=n(k,d,H),Z===null?_=k:Z.sibling=k,Z=k,U=Rl}if(H===o.length)return u(y,U),$&&Du(y,H),_;if(U===null){for(;H<o.length;H++)U=E(y,o[H],S),U!==null&&(d=n(U,d,H),Z===null?_=U:Z.sibling=U,Z=U);return $&&Du(y,H),_}for(U=a(U);H<o.length;H++)Rl=m(U,y,H,o[H],S),Rl!==null&&(l&&Rl.alternate!==null&&U.delete(Rl.key===null?H:Rl.key),d=n(Rl,d,H),Z===null?_=Rl:Z.sibling=Rl,Z=Rl);return l&&U.forEach(function(Su){return t(y,Su)}),$&&Du(y,H),_}function B(y,d,o,S){if(o==null)throw Error(r(151));for(var _=null,Z=null,U=d,H=d=0,Rl=null,k=o.next();U!==null&&!k.done;H++,k=o.next()){U.index>H?(Rl=U,U=null):Rl=U.sibling;var Su=h(y,U,k.value,S);if(Su===null){U===null&&(U=Rl);break}l&&U&&Su.alternate===null&&t(y,U),d=n(Su,d,H),Z===null?_=Su:Z.sibling=Su,Z=Su,U=Rl}if(k.done)return u(y,U),$&&Du(y,H),_;if(U===null){for(;!k.done;H++,k=o.next())k=E(y,k.value,S),k!==null&&(d=n(k,d,H),Z===null?_=k:Z.sibling=k,Z=k);return $&&Du(y,H),_}for(U=a(U);!k.done;H++,k=o.next())k=m(U,y,H,k.value,S),k!==null&&(l&&k.alternate!==null&&U.delete(k.key===null?H:k.key),d=n(k,d,H),Z===null?_=k:Z.sibling=k,Z=k);return l&&U.forEach(function(go){return t(y,go)}),$&&Du(y,H),_}function ml(y,d,o,S){if(typeof o=="object"&&o!==null&&o.type===D&&o.key===null&&(o=o.props.children),typeof o=="object"&&o!==null){switch(o.$$typeof){case fl:l:{for(var _=o.key;d!==null;){if(d.key===_){if(_=o.type,_===D){if(d.tag===7){u(y,d.sibling),S=e(d,o.props.children),S.return=y,y=S;break l}}else if(d.elementType===_||typeof _=="object"&&_!==null&&_.$$typeof===Gl&&ds(_)===d.type){u(y,d.sibling),S=e(d,o.props),Ka(S,o),S.return=y,y=S;break l}u(y,d);break}else t(y,d);d=d.sibling}o.type===D?(S=ju(o.props.children,y.mode,S,o.key),S.return=y,y=S):(S=hn(o.type,o.key,o.props,null,y.mode,S),Ka(S,o),S.return=y,y=S)}return f(y);case al:l:{for(_=o.key;d!==null;){if(d.key===_)if(d.tag===4&&d.stateNode.containerInfo===o.containerInfo&&d.stateNode.implementation===o.implementation){u(y,d.sibling),S=e(d,o.children||[]),S.return=y,y=S;break l}else{u(y,d);break}else t(y,d);d=d.sibling}S=oc(o,y.mode,S),S.return=y,y=S}return f(y);case Gl:return _=o._init,o=_(o._payload),ml(y,d,o,S)}if(R(o))return M(y,d,o,S);if(Cl(o)){if(_=Cl(o),typeof _!="function")throw Error(r(150));return o=_.call(o),B(y,d,o,S)}if(typeof o.then=="function")return ml(y,d,We(o),S);if(o.$$typeof===cl)return ml(y,d,vn(y,o),S);$e(y,o)}return typeof o=="string"&&o!==""||typeof o=="number"||typeof o=="bigint"?(o=""+o,d!==null&&d.tag===6?(u(y,d.sibling),S=e(d,o),S.return=y,y=S):(u(y,d),S=yc(o,y.mode,S),S.return=y,y=S),f(y)):u(y,d)}return function(y,d,o,S){try{La=0;var _=ml(y,d,o,S);return aa=null,_}catch(U){if(U===xa)throw U;var Z=dt(29,U,null,y.mode);return Z.lanes=S,Z.return=y,Z}finally{}}}var Uu=vs(!0),ys=vs(!1),ea=ll(null),ke=ll(0);function os(l,t){l=Vt,vl(ke,l),vl(ea,t),Vt=l|t.baseLanes}function bf(){vl(ke,Vt),vl(ea,ea.current)}function Ef(){Vt=ke.current,bl(ea),bl(ke)}var ct=ll(null),At=null;function lu(l){var t=l.alternate;vl(zl,zl.current&1),vl(ct,l),At===null&&(t===null||ea.current!==null||t.memoizedState!==null)&&(At=l)}function hs(l){if(l.tag===22){if(vl(zl,zl.current),vl(ct,l),At===null){var t=l.alternate;t!==null&&t.memoizedState!==null&&(At=l)}}else tu()}function tu(){vl(zl,zl.current),vl(ct,ct.current)}function qt(l){bl(ct),At===l&&(At=null),bl(zl)}var zl=ll(0);function Fe(l){for(var t=l;t!==null;){if(t.tag===13){var u=t.memoizedState;if(u!==null&&(u=u.dehydrated,u===null||u.data==="$?"||u.data==="$!"))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if(t.flags&128)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var ay=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(u,a){l.push(a)}};this.abort=function(){t.aborted=!0,l.forEach(function(u){return u()})}},ey=A.unstable_scheduleCallback,ny=A.unstable_NormalPriority,Ol={$$typeof:cl,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Tf(){return{controller:new ay,data:new Map,refCount:0}}function Ja(l){l.refCount--,l.refCount===0&&ey(ny,function(){l.controller.abort()})}var wa=null,Af=0,na=0,fa=null;function fy(l,t){if(wa===null){var u=wa=[];Af=0,na=Uc(),fa={status:"pending",value:void 0,then:function(a){u.push(a)}}}return Af++,t.then(rs,rs),t}function rs(){if(--Af===0&&wa!==null){fa!==null&&(fa.status="fulfilled");var l=wa;wa=null,na=0,fa=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function cy(l,t){var u=[],a={status:"pending",value:null,reason:null,then:function(e){u.push(e)}};return l.then(function(){a.status="fulfilled",a.value=t;for(var e=0;e<u.length;e++)(0,u[e])(t)},function(e){for(a.status="rejected",a.reason=e,e=0;e<u.length;e++)(0,u[e])(void 0)}),a}var ms=N.S;N.S=function(l,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&fy(l,t),ms!==null&&ms(l,t)};var Ru=ll(null);function zf(){var l=Ru.current;return l!==null?l:sl.pooledCache}function Pe(l,t){t===null?vl(Ru,Ru.current):vl(Ru,t.pool)}function gs(){var l=zf();return l===null?null:{parent:Ol._currentValue,pool:l}}var uu=0,C=null,tl=null,El=null,Ie=!1,ca=!1,Hu=!1,ln=0,Wa=0,ia=null,iy=0;function gl(){throw Error(r(321))}function Of(l,t){if(t===null)return!1;for(var u=0;u<t.length&&u<l.length;u++)if(!Wl(l[u],t[u]))return!1;return!0}function _f(l,t,u,a,e,n){return uu=n,C=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,N.H=l===null||l.memoizedState===null?Nu:au,Hu=!1,n=u(a,e),Hu=!1,ca&&(n=bs(t,u,a,e)),Ss(l),n}function Ss(l){N.H=zt;var t=tl!==null&&tl.next!==null;if(uu=0,El=tl=C=null,Ie=!1,Wa=0,ia=null,t)throw Error(r(300));l===null||Ml||(l=l.dependencies,l!==null&&dn(l)&&(Ml=!0))}function bs(l,t,u,a){C=l;var e=0;do{if(ca&&(ia=null),Wa=0,ca=!1,25<=e)throw Error(r(301));if(e+=1,El=tl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}N.H=pu,n=t(u,a)}while(ca);return n}function sy(){var l=N.H,t=l.useState()[0];return t=typeof t.then=="function"?$a(t):t,l=l.useState()[0],(tl!==null?tl.memoizedState:null)!==l&&(C.flags|=1024),t}function Df(){var l=ln!==0;return ln=0,l}function Mf(l,t,u){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~u}function Uf(l){if(Ie){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}Ie=!1}uu=0,El=tl=C=null,ca=!1,Wa=ln=0,ia=null}function Ll(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return El===null?C.memoizedState=El=l:El=El.next=l,El}function Tl(){if(tl===null){var l=C.alternate;l=l!==null?l.memoizedState:null}else l=tl.next;var t=El===null?C.memoizedState:El.next;if(t!==null)El=t,tl=l;else{if(l===null)throw C.alternate===null?Error(r(467)):Error(r(310));tl=l,l={memoizedState:tl.memoizedState,baseState:tl.baseState,baseQueue:tl.baseQueue,queue:tl.queue,next:null},El===null?C.memoizedState=El=l:El=El.next=l}return El}var tn;tn=function(){return{lastEffect:null,events:null,stores:null,memoCache:null}};function $a(l){var t=Wa;return Wa+=1,ia===null&&(ia=[]),l=is(ia,l,t),t=C,(El===null?t.memoizedState:El.next)===null&&(t=t.alternate,N.H=t===null||t.memoizedState===null?Nu:au),l}function un(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return $a(l);if(l.$$typeof===cl)return Yl(l)}throw Error(r(438,String(l)))}function Rf(l){var t=null,u=C.updateQueue;if(u!==null&&(t=u.memoCache),t==null){var a=C.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),u===null&&(u=tn(),C.updateQueue=u),u.memoCache=t,u=t.data[t.index],u===void 0)for(u=t.data[t.index]=Array(l),a=0;a<l;a++)u[a]=Jt;return t.index++,u}function Yt(l,t){return typeof t=="function"?t(l):t}function an(l){var t=Tl();return Hf(t,tl,l)}function Hf(l,t,u){var a=l.queue;if(a===null)throw Error(r(311));a.lastRenderedReducer=u;var e=l.baseQueue,n=a.pending;if(n!==null){if(e!==null){var f=e.next;e.next=n.next,n.next=f}t.baseQueue=e=n,a.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var c=f=null,i=null,v=t,g=!1;do{var E=v.lane&-536870913;if(E!==v.lane?(J&E)===E:(uu&E)===E){var h=v.revertLane;if(h===0)i!==null&&(i=i.next={lane:0,revertLane:0,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null}),E===na&&(g=!0);else if((uu&h)===h){v=v.next,h===na&&(g=!0);continue}else E={lane:0,revertLane:v.revertLane,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},i===null?(c=i=E,f=n):i=i.next=E,C.lanes|=h,yu|=h;E=v.action,Hu&&u(n,E),n=v.hasEagerState?v.eagerState:u(n,E)}else h={lane:E,revertLane:v.revertLane,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},i===null?(c=i=h,f=n):i=i.next=h,C.lanes|=E,yu|=E;v=v.next}while(v!==null&&v!==t);if(i===null?f=n:i.next=c,!Wl(n,l.memoizedState)&&(Ml=!0,g&&(u=fa,u!==null)))throw u;l.memoizedState=n,l.baseState=f,l.baseQueue=i,a.lastRenderedState=n}return e===null&&(a.lanes=0),[l.memoizedState,a.dispatch]}function Nf(l){var t=Tl(),u=t.queue;if(u===null)throw Error(r(311));u.lastRenderedReducer=l;var a=u.dispatch,e=u.pending,n=t.memoizedState;if(e!==null){u.pending=null;var f=e=e.next;do n=l(n,f.action),f=f.next;while(f!==e);Wl(n,t.memoizedState)||(Ml=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),u.lastRenderedState=n}return[n,a]}function Es(l,t,u){var a=C,e=Tl(),n=$;if(n){if(u===void 0)throw Error(r(407));u=u()}else u=t();var f=!Wl((tl||e).memoizedState,u);if(f&&(e.memoizedState=u,Ml=!0),e=e.queue,Yf(zs.bind(null,a,e,l),[l]),e.getSnapshot!==t||f||El!==null&&El.memoizedState.tag&1){if(a.flags|=2048,sa(9,As.bind(null,a,e,u,t),{destroy:void 0},null),sl===null)throw Error(r(349));n||uu&60||Ts(a,t,u)}return u}function Ts(l,t,u){l.flags|=16384,l={getSnapshot:t,value:u},t=C.updateQueue,t===null?(t=tn(),C.updateQueue=t,t.stores=[l]):(u=t.stores,u===null?t.stores=[l]:u.push(l))}function As(l,t,u,a){t.value=u,t.getSnapshot=a,Os(t)&&_s(l)}function zs(l,t,u){return u(function(){Os(t)&&_s(l)})}function Os(l){var t=l.getSnapshot;l=l.value;try{var u=t();return!Wl(l,u)}catch{return!0}}function _s(l){var t=It(l,2);t!==null&&Ql(t,l,2)}function pf(l){var t=Ll();if(typeof l=="function"){var u=l;if(l=u(),Hu){kt(!0);try{u()}finally{kt(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Yt,lastRenderedState:l},t}function Ds(l,t,u,a){return l.baseState=u,Hf(l,tl,typeof a=="function"?a:Yt)}function dy(l,t,u,a,e){if(fn(l))throw Error(r(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(f){n.listeners.push(f)}};N.T!==null?u(!0):n.isTransition=!1,a(n),u=t.pending,u===null?(n.next=t.pending=n,Ms(t,n)):(n.next=u.next,t.pending=u.next=n)}}function Ms(l,t){var u=t.action,a=t.payload,e=l.state;if(t.isTransition){var n=N.T,f={};N.T=f;try{var c=u(e,a),i=N.S;i!==null&&i(f,c),Us(l,t,c)}catch(v){qf(l,t,v)}finally{N.T=n}}else try{n=u(e,a),Us(l,t,n)}catch(v){qf(l,t,v)}}function Us(l,t,u){u!==null&&typeof u=="object"&&typeof u.then=="function"?u.then(function(a){Rs(l,t,a)},function(a){return qf(l,t,a)}):Rs(l,t,u)}function Rs(l,t,u){t.status="fulfilled",t.value=u,Hs(t),l.state=u,t=l.pending,t!==null&&(u=t.next,u===t?l.pending=null:(u=u.next,t.next=u,Ms(l,u)))}function qf(l,t,u){var a=l.pending;if(l.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=u,Hs(t),t=t.next;while(t!==a)}l.action=null}function Hs(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function Ns(l,t){return t}function ps(l,t){if($){var u=sl.formState;if(u!==null){l:{var a=C;if($){if(Hl){t:{for(var e=Hl,n=Tt;e.nodeType!==8;){if(!n){e=null;break t}if(e=gt(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){Hl=gt(e.nextSibling),a=e.data==="F!";break l}}Mu(a)}a=!1}a&&(t=u[0])}}return u=Ll(),u.memoizedState=u.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ns,lastRenderedState:t},u.queue=a,u=ks.bind(null,C,a),a.dispatch=u,a=pf(!1),n=Qf.bind(null,C,!1,a.queue),a=Ll(),e={state:t,dispatch:null,action:l,pending:null},a.queue=e,u=dy.bind(null,C,e,n,u),e.dispatch=u,a.memoizedState=l,[t,u,!1]}function qs(l){var t=Tl();return Ys(t,tl,l)}function Ys(l,t,u){t=Hf(l,t,Ns)[0],l=an(Yt)[0],t=typeof t=="object"&&t!==null&&typeof t.then=="function"?$a(t):t;var a=Tl(),e=a.queue,n=e.dispatch;return u!==a.memoizedState&&(C.flags|=2048,sa(9,vy.bind(null,e,u),{destroy:void 0},null)),[t,n,l]}function vy(l,t){l.action=t}function Bs(l){var t=Tl(),u=tl;if(u!==null)return Ys(t,u,l);Tl(),t=t.memoizedState,u=Tl();var a=u.queue.dispatch;return u.memoizedState=l,[t,a,!1]}function sa(l,t,u,a){return l={tag:l,create:t,inst:u,deps:a,next:null},t=C.updateQueue,t===null&&(t=tn(),C.updateQueue=t),u=t.lastEffect,u===null?t.lastEffect=l.next=l:(a=u.next,u.next=l,l.next=a,t.lastEffect=l),l}function Gs(){return Tl().memoizedState}function en(l,t,u,a){var e=Ll();C.flags|=l,e.memoizedState=sa(1|t,u,{destroy:void 0},a===void 0?null:a)}function nn(l,t,u,a){var e=Tl();a=a===void 0?null:a;var n=e.memoizedState.inst;tl!==null&&a!==null&&Of(a,tl.memoizedState.deps)?e.memoizedState=sa(t,u,n,a):(C.flags|=l,e.memoizedState=sa(1|t,u,n,a))}function js(l,t){en(8390656,8,l,t)}function Yf(l,t){nn(2048,8,l,t)}function Xs(l,t){return nn(4,2,l,t)}function Qs(l,t){return nn(4,4,l,t)}function Cs(l,t){if(typeof t=="function"){l=l();var u=t(l);return function(){typeof u=="function"?u():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function Zs(l,t,u){u=u!=null?u.concat([l]):null,nn(4,4,Cs.bind(null,t,l),u)}function Bf(){}function xs(l,t){var u=Tl();t=t===void 0?null:t;var a=u.memoizedState;return t!==null&&Of(t,a[1])?a[0]:(u.memoizedState=[l,t],l)}function Vs(l,t){var u=Tl();t=t===void 0?null:t;var a=u.memoizedState;if(t!==null&&Of(t,a[1]))return a[0];if(a=l(),Hu){kt(!0);try{l()}finally{kt(!1)}}return u.memoizedState=[a,t],a}function Gf(l,t,u){return u===void 0||uu&1073741824?l.memoizedState=t:(l.memoizedState=u,l=K0(),C.lanes|=l,yu|=l,u)}function Ls(l,t,u,a){return Wl(u,t)?u:ea.current!==null?(l=Gf(l,u,a),Wl(l,t)||(Ml=!0),l):uu&42?(l=K0(),C.lanes|=l,yu|=l,t):(Ml=!0,l.memoizedState=u)}function Ks(l,t,u,a,e){var n=O.p;O.p=n!==0&&8>n?n:8;var f=N.T,c={};N.T=c,Qf(l,!1,t,u);try{var i=e(),v=N.S;if(v!==null&&v(c,i),i!==null&&typeof i=="object"&&typeof i.then=="function"){var g=cy(i,a);ka(l,t,g,Pl(l))}else ka(l,t,a,Pl(l))}catch(E){ka(l,t,{then:function(){},status:"rejected",reason:E},Pl())}finally{O.p=n,N.T=f}}function yy(){}function jf(l,t,u,a){if(l.tag!==5)throw Error(r(476));var e=Js(l).queue;Ks(l,e,t,K,u===null?yy:function(){return ws(l),u(a)})}function Js(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:K,baseState:K,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Yt,lastRenderedState:K},next:null};var u={};return t.next={memoizedState:u,baseState:u,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Yt,lastRenderedState:u},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function ws(l){var t=Js(l).next.queue;ka(l,t,{},Pl())}function Xf(){return Yl(me)}function Ws(){return Tl().memoizedState}function $s(){return Tl().memoizedState}function oy(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var u=Pl();l=fu(u);var a=cu(t,l,u);a!==null&&(Ql(a,t,u),Ia(a,t,u)),t={cache:Tf()},l.payload=t;return}t=t.return}}function hy(l,t,u){var a=Pl();u={lane:a,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null},fn(l)?Fs(t,u):(u=hf(l,t,u,a),u!==null&&(Ql(u,l,a),Ps(u,t,a)))}function ks(l,t,u){var a=Pl();ka(l,t,u,a)}function ka(l,t,u,a){var e={lane:a,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null};if(fn(l))Fs(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var f=t.lastRenderedState,c=n(f,u);if(e.hasEagerState=!0,e.eagerState=c,Wl(c,f))return Ve(l,t,e,0),sl===null&&xe(),!1}catch{}finally{}if(u=hf(l,t,e,a),u!==null)return Ql(u,l,a),Ps(u,t,a),!0}return!1}function Qf(l,t,u,a){if(a={lane:2,revertLane:Uc(),action:a,hasEagerState:!1,eagerState:null,next:null},fn(l)){if(t)throw Error(r(479))}else t=hf(l,u,a,2),t!==null&&Ql(t,l,2)}function fn(l){var t=l.alternate;return l===C||t!==null&&t===C}function Fs(l,t){ca=Ie=!0;var u=l.pending;u===null?t.next=t:(t.next=u.next,u.next=t),l.pending=t}function Ps(l,t,u){if(u&4194176){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,si(l,u)}}var zt={readContext:Yl,use:un,useCallback:gl,useContext:gl,useEffect:gl,useImperativeHandle:gl,useLayoutEffect:gl,useInsertionEffect:gl,useMemo:gl,useReducer:gl,useRef:gl,useState:gl,useDebugValue:gl,useDeferredValue:gl,useTransition:gl,useSyncExternalStore:gl,useId:gl};zt.useCacheRefresh=gl,zt.useMemoCache=gl,zt.useHostTransitionStatus=gl,zt.useFormState=gl,zt.useActionState=gl,zt.useOptimistic=gl;var Nu={readContext:Yl,use:un,useCallback:function(l,t){return Ll().memoizedState=[l,t===void 0?null:t],l},useContext:Yl,useEffect:js,useImperativeHandle:function(l,t,u){u=u!=null?u.concat([l]):null,en(4194308,4,Cs.bind(null,t,l),u)},useLayoutEffect:function(l,t){return en(4194308,4,l,t)},useInsertionEffect:function(l,t){en(4,2,l,t)},useMemo:function(l,t){var u=Ll();t=t===void 0?null:t;var a=l();if(Hu){kt(!0);try{l()}finally{kt(!1)}}return u.memoizedState=[a,t],a},useReducer:function(l,t,u){var a=Ll();if(u!==void 0){var e=u(t);if(Hu){kt(!0);try{u(t)}finally{kt(!1)}}}else e=t;return a.memoizedState=a.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},a.queue=l,l=l.dispatch=hy.bind(null,C,l),[a.memoizedState,l]},useRef:function(l){var t=Ll();return l={current:l},t.memoizedState=l},useState:function(l){l=pf(l);var t=l.queue,u=ks.bind(null,C,t);return t.dispatch=u,[l.memoizedState,u]},useDebugValue:Bf,useDeferredValue:function(l,t){var u=Ll();return Gf(u,l,t)},useTransition:function(){var l=pf(!1);return l=Ks.bind(null,C,l.queue,!0,!1),Ll().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,u){var a=C,e=Ll();if($){if(u===void 0)throw Error(r(407));u=u()}else{if(u=t(),sl===null)throw Error(r(349));J&60||Ts(a,t,u)}e.memoizedState=u;var n={value:u,getSnapshot:t};return e.queue=n,js(zs.bind(null,a,n,l),[l]),a.flags|=2048,sa(9,As.bind(null,a,n,u,t),{destroy:void 0},null),u},useId:function(){var l=Ll(),t=sl.identifierPrefix;if($){var u=pt,a=Nt;u=(a&~(1<<32-wl(a)-1)).toString(32)+u,t=":"+t+"R"+u,u=ln++,0<u&&(t+="H"+u.toString(32)),t+=":"}else u=iy++,t=":"+t+"r"+u.toString(32)+":";return l.memoizedState=t},useCacheRefresh:function(){return Ll().memoizedState=oy.bind(null,C)}};Nu.useMemoCache=Rf,Nu.useHostTransitionStatus=Xf,Nu.useFormState=ps,Nu.useActionState=ps,Nu.useOptimistic=function(l){var t=Ll();t.memoizedState=t.baseState=l;var u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=u,t=Qf.bind(null,C,!0,u),u.dispatch=t,[l,t]};var au={readContext:Yl,use:un,useCallback:xs,useContext:Yl,useEffect:Yf,useImperativeHandle:Zs,useInsertionEffect:Xs,useLayoutEffect:Qs,useMemo:Vs,useReducer:an,useRef:Gs,useState:function(){return an(Yt)},useDebugValue:Bf,useDeferredValue:function(l,t){var u=Tl();return Ls(u,tl.memoizedState,l,t)},useTransition:function(){var l=an(Yt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:$a(l),t]},useSyncExternalStore:Es,useId:Ws};au.useCacheRefresh=$s,au.useMemoCache=Rf,au.useHostTransitionStatus=Xf,au.useFormState=qs,au.useActionState=qs,au.useOptimistic=function(l,t){var u=Tl();return Ds(u,tl,l,t)};var pu={readContext:Yl,use:un,useCallback:xs,useContext:Yl,useEffect:Yf,useImperativeHandle:Zs,useInsertionEffect:Xs,useLayoutEffect:Qs,useMemo:Vs,useReducer:Nf,useRef:Gs,useState:function(){return Nf(Yt)},useDebugValue:Bf,useDeferredValue:function(l,t){var u=Tl();return tl===null?Gf(u,l,t):Ls(u,tl.memoizedState,l,t)},useTransition:function(){var l=Nf(Yt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:$a(l),t]},useSyncExternalStore:Es,useId:Ws};pu.useCacheRefresh=$s,pu.useMemoCache=Rf,pu.useHostTransitionStatus=Xf,pu.useFormState=Bs,pu.useActionState=Bs,pu.useOptimistic=function(l,t){var u=Tl();return tl!==null?Ds(u,tl,l,t):(u.baseState=l,[l,u.queue.dispatch])};function Cf(l,t,u,a){t=l.memoizedState,u=u(a,t),u=u==null?t:P({},t,u),l.memoizedState=u,l.lanes===0&&(l.updateQueue.baseState=u)}var Zf={isMounted:function(l){return(l=l._reactInternals)?Y(l)===l:!1},enqueueSetState:function(l,t,u){l=l._reactInternals;var a=Pl(),e=fu(a);e.payload=t,u!=null&&(e.callback=u),t=cu(l,e,a),t!==null&&(Ql(t,l,a),Ia(t,l,a))},enqueueReplaceState:function(l,t,u){l=l._reactInternals;var a=Pl(),e=fu(a);e.tag=1,e.payload=t,u!=null&&(e.callback=u),t=cu(l,e,a),t!==null&&(Ql(t,l,a),Ia(t,l,a))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var u=Pl(),a=fu(u);a.tag=2,t!=null&&(a.callback=t),t=cu(l,a,u),t!==null&&(Ql(t,l,u),Ia(t,l,u))}};function Is(l,t,u,a,e,n,f){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(a,n,f):t.prototype&&t.prototype.isPureReactComponent?!ja(u,a)||!ja(e,n):!0}function l0(l,t,u,a){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(u,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(u,a),t.state!==l&&Zf.enqueueReplaceState(t,t.state,null)}function qu(l,t){var u=t;if("ref"in t){u={};for(var a in t)a!=="ref"&&(u[a]=t[a])}if(l=l.defaultProps){u===t&&(u=P({},u));for(var e in l)u[e]===void 0&&(u[e]=l[e])}return u}var cn=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)};function t0(l){cn(l)}function u0(l){console.error(l)}function a0(l){cn(l)}function sn(l,t){try{var u=l.onUncaughtError;u(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function e0(l,t,u){try{var a=l.onCaughtError;a(u.value,{componentStack:u.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function xf(l,t,u){return u=fu(u),u.tag=3,u.payload={element:null},u.callback=function(){sn(l,t)},u}function n0(l){return l=fu(l),l.tag=3,l}function f0(l,t,u,a){var e=u.type.getDerivedStateFromError;if(typeof e=="function"){var n=a.value;l.payload=function(){return e(n)},l.callback=function(){e0(t,u,a)}}var f=u.stateNode;f!==null&&typeof f.componentDidCatch=="function"&&(l.callback=function(){e0(t,u,a),typeof e!="function"&&(ou===null?ou=new Set([this]):ou.add(this));var c=a.stack;this.componentDidCatch(a.value,{componentStack:c!==null?c:""})})}function ry(l,t,u,a,e){if(u.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=u.alternate,t!==null&&Pa(t,u,e,!0),u=ct.current,u!==null){switch(u.tag){case 13:return At===null?zc():u.alternate===null&&rl===0&&(rl=3),u.flags&=-257,u.flags|=65536,u.lanes=e,a===Sf?u.flags|=16384:(t=u.updateQueue,t===null?u.updateQueue=new Set([a]):t.add(a),_c(l,a,e)),!1;case 22:return u.flags|=65536,a===Sf?u.flags|=16384:(t=u.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},u.updateQueue=t):(u=t.retryQueue,u===null?t.retryQueue=new Set([a]):u.add(a)),_c(l,a,e)),!1}throw Error(r(435,u.tag))}return _c(l,a,e),zc(),!1}if($)return t=ct.current,t!==null?(!(t.flags&65536)&&(t.flags|=256),t.flags|=65536,t.lanes=e,a!==gf&&(l=Error(r(422),{cause:a}),Za(et(l,u)))):(a!==gf&&(t=Error(r(423),{cause:a}),Za(et(t,u))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,a=et(a,u),e=xf(l.stateNode,a,e),ac(l,e),rl!==4&&(rl=2)),!1;var n=Error(r(520),{cause:a});if(n=et(n,u),ce===null?ce=[n]:ce.push(n),rl!==4&&(rl=2),t===null)return!0;a=et(a,u),u=t;do{switch(u.tag){case 3:return u.flags|=65536,l=e&-e,u.lanes|=l,l=xf(u.stateNode,a,l),ac(u,l),!1;case 1:if(t=u.type,n=u.stateNode,(u.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(ou===null||!ou.has(n))))return u.flags|=65536,e&=-e,u.lanes|=e,e=n0(e),f0(e,l,u,a),ac(u,e),!1}u=u.return}while(u!==null);return!1}var c0=Error(r(461)),Ml=!1;function Nl(l,t,u,a){t.child=l===null?ys(t,null,u,a):Uu(t,l.child,u,a)}function i0(l,t,u,a,e){u=u.render;var n=t.ref;if("ref"in a){var f={};for(var c in a)c!=="ref"&&(f[c]=a[c])}else f=a;return Bu(t),a=_f(l,t,u,f,n,e),c=Df(),l!==null&&!Ml?(Mf(l,t,e),Bt(l,t,e)):($&&c&&rf(t),t.flags|=1,Nl(l,t,a,e),t.child)}function s0(l,t,u,a,e){if(l===null){var n=u.type;return typeof n=="function"&&!vc(n)&&n.defaultProps===void 0&&u.compare===null?(t.tag=15,t.type=n,d0(l,t,n,a,e)):(l=hn(u.type,null,a,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!Ff(l,e)){var f=n.memoizedProps;if(u=u.compare,u=u!==null?u:ja,u(f,a)&&l.ref===t.ref)return Bt(l,t,e)}return t.flags|=1,l=vu(n,a),l.ref=t.ref,l.return=t,t.child=l}function d0(l,t,u,a,e){if(l!==null){var n=l.memoizedProps;if(ja(n,a)&&l.ref===t.ref)if(Ml=!1,t.pendingProps=a=n,Ff(l,e))l.flags&131072&&(Ml=!0);else return t.lanes=l.lanes,Bt(l,t,e)}return Vf(l,t,u,a,e)}function v0(l,t,u){var a=t.pendingProps,e=a.children,n=(t.stateNode._pendingVisibility&2)!==0,f=l!==null?l.memoizedState:null;if(Fa(l,t),a.mode==="hidden"||n){if(t.flags&128){if(a=f!==null?f.baseLanes|u:u,l!==null){for(e=t.child=l.child,n=0;e!==null;)n=n|e.lanes|e.childLanes,e=e.sibling;t.childLanes=n&~a}else t.childLanes=0,t.child=null;return y0(l,t,a,u)}if(u&536870912)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&Pe(t,f!==null?f.cachePool:null),f!==null?os(t,f):bf(),hs(t);else return t.lanes=t.childLanes=536870912,y0(l,t,f!==null?f.baseLanes|u:u,u)}else f!==null?(Pe(t,f.cachePool),os(t,f),tu(),t.memoizedState=null):(l!==null&&Pe(t,null),bf(),tu());return Nl(l,t,e,u),t.child}function y0(l,t,u,a){var e=zf();return e=e===null?null:{parent:Ol._currentValue,pool:e},t.memoizedState={baseLanes:u,cachePool:e},l!==null&&Pe(t,null),bf(),hs(t),l!==null&&Pa(l,t,a,!0),null}function Fa(l,t){var u=t.ref;if(u===null)l!==null&&l.ref!==null&&(t.flags|=2097664);else{if(typeof u!="function"&&typeof u!="object")throw Error(r(284));(l===null||l.ref!==u)&&(t.flags|=2097664)}}function Vf(l,t,u,a,e){return Bu(t),u=_f(l,t,u,a,void 0,e),a=Df(),l!==null&&!Ml?(Mf(l,t,e),Bt(l,t,e)):($&&a&&rf(t),t.flags|=1,Nl(l,t,u,e),t.child)}function o0(l,t,u,a,e,n){return Bu(t),t.updateQueue=null,u=bs(t,a,u,e),Ss(l),a=Df(),l!==null&&!Ml?(Mf(l,t,n),Bt(l,t,n)):($&&a&&rf(t),t.flags|=1,Nl(l,t,u,n),t.child)}function h0(l,t,u,a,e){if(Bu(t),t.stateNode===null){var n=la,f=u.contextType;typeof f=="object"&&f!==null&&(n=Yl(f)),n=new u(a,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=Zf,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=a,n.state=t.memoizedState,n.refs={},tc(t),f=u.contextType,n.context=typeof f=="object"&&f!==null?Yl(f):la,n.state=t.memoizedState,f=u.getDerivedStateFromProps,typeof f=="function"&&(Cf(t,u,f,a),n.state=t.memoizedState),typeof u.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(f=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),f!==n.state&&Zf.enqueueReplaceState(n,n.state,null),te(t,a,n,e),le(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(l===null){n=t.stateNode;var c=t.memoizedProps,i=qu(u,c);n.props=i;var v=n.context,g=u.contextType;f=la,typeof g=="object"&&g!==null&&(f=Yl(g));var E=u.getDerivedStateFromProps;g=typeof E=="function"||typeof n.getSnapshotBeforeUpdate=="function",c=t.pendingProps!==c,g||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(c||v!==f)&&l0(t,n,a,f),nu=!1;var h=t.memoizedState;n.state=h,te(t,a,n,e),le(),v=t.memoizedState,c||h!==v||nu?(typeof E=="function"&&(Cf(t,u,E,a),v=t.memoizedState),(i=nu||Is(t,u,i,a,h,v,f))?(g||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=v),n.props=a,n.state=v,n.context=f,a=i):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{n=t.stateNode,uc(l,t),f=t.memoizedProps,g=qu(u,f),n.props=g,E=t.pendingProps,h=n.context,v=u.contextType,i=la,typeof v=="object"&&v!==null&&(i=Yl(v)),c=u.getDerivedStateFromProps,(v=typeof c=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f!==E||h!==i)&&l0(t,n,a,i),nu=!1,h=t.memoizedState,n.state=h,te(t,a,n,e),le();var m=t.memoizedState;f!==E||h!==m||nu||l!==null&&l.dependencies!==null&&dn(l.dependencies)?(typeof c=="function"&&(Cf(t,u,c,a),m=t.memoizedState),(g=nu||Is(t,u,g,a,h,m,i)||l!==null&&l.dependencies!==null&&dn(l.dependencies))?(v||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(a,m,i),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(a,m,i)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=m),n.props=a,n.state=m,n.context=i,a=g):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=1024),a=!1)}return n=a,Fa(l,t),a=(t.flags&128)!==0,n||a?(n=t.stateNode,u=a&&typeof u.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&a?(t.child=Uu(t,l.child,null,e),t.child=Uu(t,null,u,e)):Nl(l,t,u,e),t.memoizedState=n.state,l=t.child):l=Bt(l,t,e),l}function r0(l,t,u,a){return Ca(),t.flags|=256,Nl(l,t,u,a),t.child}var Lf={dehydrated:null,treeContext:null,retryLane:0};function Kf(l){return{baseLanes:l,cachePool:gs()}}function Jf(l,t,u){return l=l!==null?l.childLanes&~u:0,t&&(l|=vt),l}function m0(l,t,u){var a=t.pendingProps,e=!1,n=(t.flags&128)!==0,f;if((f=n)||(f=l!==null&&l.memoizedState===null?!1:(zl.current&2)!==0),f&&(e=!0,t.flags&=-129),f=(t.flags&32)!==0,t.flags&=-33,l===null){if($){if(e?lu(t):tu(),$){var c=Hl,i;if(i=c){l:{for(i=c,c=Tt;i.nodeType!==8;){if(!c){c=null;break l}if(i=gt(i.nextSibling),i===null){c=null;break l}}c=i}c!==null?(t.memoizedState={dehydrated:c,treeContext:_u!==null?{id:Nt,overflow:pt}:null,retryLane:536870912},i=dt(18,null,null,0),i.stateNode=c,i.return=t,t.child=i,Xl=t,Hl=null,i=!0):i=!1}i||Mu(t)}if(c=t.memoizedState,c!==null&&(c=c.dehydrated,c!==null))return c.data==="$!"?t.lanes=16:t.lanes=536870912,null;qt(t)}return c=a.children,a=a.fallback,e?(tu(),e=t.mode,c=Wf({mode:"hidden",children:c},e),a=ju(a,e,u,null),c.return=t,a.return=t,c.sibling=a,t.child=c,e=t.child,e.memoizedState=Kf(u),e.childLanes=Jf(l,f,u),t.memoizedState=Lf,a):(lu(t),wf(t,c))}if(i=l.memoizedState,i!==null&&(c=i.dehydrated,c!==null)){if(n)t.flags&256?(lu(t),t.flags&=-257,t=$f(l,t,u)):t.memoizedState!==null?(tu(),t.child=l.child,t.flags|=128,t=null):(tu(),e=a.fallback,c=t.mode,a=Wf({mode:"visible",children:a.children},c),e=ju(e,c,u,null),e.flags|=2,a.return=t,e.return=t,a.sibling=e,t.child=a,Uu(t,l.child,null,u),a=t.child,a.memoizedState=Kf(u),a.childLanes=Jf(l,f,u),t.memoizedState=Lf,t=e);else if(lu(t),c.data==="$!"){if(f=c.nextSibling&&c.nextSibling.dataset,f)var v=f.dgst;f=v,a=Error(r(419)),a.stack="",a.digest=f,Za({value:a,source:null,stack:null}),t=$f(l,t,u)}else if(Ml||Pa(l,t,u,!1),f=(u&l.childLanes)!==0,Ml||f){if(f=sl,f!==null){if(a=u&-u,a&42)a=1;else switch(a){case 2:a=1;break;case 8:a=4;break;case 32:a=16;break;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:a=64;break;case 268435456:a=134217728;break;default:a=0}if(a=a&(f.suspendedLanes|u)?0:a,a!==0&&a!==i.retryLane)throw i.retryLane=a,It(l,a),Ql(f,l,a),c0}c.data==="$?"||zc(),t=$f(l,t,u)}else c.data==="$?"?(t.flags|=128,t.child=l.child,t=Hy.bind(null,l),c._reactRetry=t,t=null):(l=i.treeContext,Hl=gt(c.nextSibling),Xl=t,$=!0,rt=null,Tt=!1,l!==null&&(nt[ft++]=Nt,nt[ft++]=pt,nt[ft++]=_u,Nt=l.id,pt=l.overflow,_u=t),t=wf(t,a.children),t.flags|=4096);return t}return e?(tu(),e=a.fallback,c=t.mode,i=l.child,v=i.sibling,a=vu(i,{mode:"hidden",children:a.children}),a.subtreeFlags=i.subtreeFlags&31457280,v!==null?e=vu(v,e):(e=ju(e,c,u,null),e.flags|=2),e.return=t,a.return=t,a.sibling=e,t.child=a,a=e,e=t.child,c=l.child.memoizedState,c===null?c=Kf(u):(i=c.cachePool,i!==null?(v=Ol._currentValue,i=i.parent!==v?{parent:v,pool:v}:i):i=gs(),c={baseLanes:c.baseLanes|u,cachePool:i}),e.memoizedState=c,e.childLanes=Jf(l,f,u),t.memoizedState=Lf,a):(lu(t),u=l.child,l=u.sibling,u=vu(u,{mode:"visible",children:a.children}),u.return=t,u.sibling=null,l!==null&&(f=t.deletions,f===null?(t.deletions=[l],t.flags|=16):f.push(l)),t.child=u,t.memoizedState=null,u)}function wf(l,t){return t=Wf({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function Wf(l,t){return x0(l,t,0,null)}function $f(l,t,u){return Uu(t,l.child,null,u),l=wf(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function g0(l,t,u){l.lanes|=t;var a=l.alternate;a!==null&&(a.lanes|=t),If(l.return,t,u)}function kf(l,t,u,a,e){var n=l.memoizedState;n===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:u,tailMode:e}:(n.isBackwards=t,n.rendering=null,n.renderingStartTime=0,n.last=a,n.tail=u,n.tailMode=e)}function S0(l,t,u){var a=t.pendingProps,e=a.revealOrder,n=a.tail;if(Nl(l,t,a.children,u),a=zl.current,a&2)a=a&1|2,t.flags|=128;else{if(l!==null&&l.flags&128)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&g0(l,u,t);else if(l.tag===19)g0(l,u,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}a&=1}switch(vl(zl,a),e){case"forwards":for(u=t.child,e=null;u!==null;)l=u.alternate,l!==null&&Fe(l)===null&&(e=u),u=u.sibling;u=e,u===null?(e=t.child,t.child=null):(e=u.sibling,u.sibling=null),kf(t,!1,e,u,n);break;case"backwards":for(u=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&Fe(l)===null){t.child=e;break}l=e.sibling,e.sibling=u,u=e,e=l}kf(t,!0,u,null,n);break;case"together":kf(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function Bt(l,t,u){if(l!==null&&(t.dependencies=l.dependencies),yu|=t.lanes,!(u&t.childLanes))if(l!==null){if(Pa(l,t,u,!1),(u&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(r(153));if(t.child!==null){for(l=t.child,u=vu(l,l.pendingProps),t.child=u,u.return=t;l.sibling!==null;)l=l.sibling,u=u.sibling=vu(l,l.pendingProps),u.return=t;u.sibling=null}return t.child}function Ff(l,t){return l.lanes&t?!0:(l=l.dependencies,!!(l!==null&&dn(l)))}function my(l,t,u){switch(t.tag){case 3:_e(t,t.stateNode.containerInfo),eu(t,Ol,l.memoizedState.cache),Ca();break;case 27:case 5:Cn(t);break;case 4:_e(t,t.stateNode.containerInfo);break;case 10:eu(t,t.type,t.memoizedProps.value);break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(lu(t),t.flags|=128,null):u&t.child.childLanes?m0(l,t,u):(lu(t),l=Bt(l,t,u),l!==null?l.sibling:null);lu(t);break;case 19:var e=(l.flags&128)!==0;if(a=(u&t.childLanes)!==0,a||(Pa(l,t,u,!1),a=(u&t.childLanes)!==0),e){if(a)return S0(l,t,u);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),vl(zl,zl.current),a)break;return null;case 22:case 23:return t.lanes=0,v0(l,t,u);case 24:eu(t,Ol,l.memoizedState.cache)}return Bt(l,t,u)}function b0(l,t,u){if(l!==null)if(l.memoizedProps!==t.pendingProps)Ml=!0;else{if(!Ff(l,u)&&!(t.flags&128))return Ml=!1,my(l,t,u);Ml=!!(l.flags&131072)}else Ml=!1,$&&t.flags&1048576&&as(t,Je,t.index);switch(t.lanes=0,t.tag){case 16:l:{l=t.pendingProps;var a=t.elementType,e=a._init;if(a=e(a._payload),t.type=a,typeof a=="function")vc(a)?(l=qu(a,l),t.tag=1,t=h0(null,t,a,l,u)):(t.tag=0,t=Vf(null,t,a,l,u));else{if(a!=null){if(e=a.$$typeof,e===_l){t.tag=11,t=i0(null,t,a,l,u);break l}else if(e===Dt){t.tag=14,t=s0(null,t,a,l,u);break l}}throw t=Wt(a)||a,Error(r(306,t,""))}}return t;case 0:return Vf(l,t,t.type,t.pendingProps,u);case 1:return a=t.type,e=qu(a,t.pendingProps),h0(l,t,a,e,u);case 3:l:{if(_e(t,t.stateNode.containerInfo),l===null)throw Error(r(387));var n=t.pendingProps;e=t.memoizedState,a=e.element,uc(l,t),te(t,n,null,u);var f=t.memoizedState;if(n=f.cache,eu(t,Ol,n),n!==e.cache&&lc(t,[Ol],u,!0),le(),n=f.element,e.isDehydrated)if(e={element:n,isDehydrated:!1,cache:f.cache},t.updateQueue.baseState=e,t.memoizedState=e,t.flags&256){t=r0(l,t,n,u);break l}else if(n!==a){a=et(Error(r(424)),t),Za(a),t=r0(l,t,n,u);break l}else for(Hl=gt(t.stateNode.containerInfo.firstChild),Xl=t,$=!0,rt=null,Tt=!0,u=ys(t,null,n,u),t.child=u;u;)u.flags=u.flags&-3|4096,u=u.sibling;else{if(Ca(),n===a){t=Bt(l,t,u);break l}Nl(l,t,n,u)}t=t.child}return t;case 26:return Fa(l,t),l===null?(u=Ad(t.type,null,t.pendingProps,null))?t.memoizedState=u:$||(u=t.type,l=t.pendingProps,a=Dn($t.current).createElement(u),a[ql]=t,a[xl]=l,pl(a,u,l),Dl(a),t.stateNode=a):t.memoizedState=Ad(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return Cn(t),l===null&&$&&(a=t.stateNode=bd(t.type,t.pendingProps,$t.current),Xl=t,Tt=!0,Hl=gt(a.firstChild)),a=t.pendingProps.children,l!==null||$?Nl(l,t,a,u):t.child=Uu(t,null,a,u),Fa(l,t),t.child;case 5:return l===null&&$&&((e=a=Hl)&&(a=Jy(a,t.type,t.pendingProps,Tt),a!==null?(t.stateNode=a,Xl=t,Hl=gt(a.firstChild),Tt=!1,e=!0):e=!1),e||Mu(t)),Cn(t),e=t.type,n=t.pendingProps,f=l!==null?l.memoizedProps:null,a=n.children,jc(e,n)?a=null:f!==null&&jc(e,f)&&(t.flags|=32),t.memoizedState!==null&&(e=_f(l,t,sy,null,null,u),me._currentValue=e),Fa(l,t),Nl(l,t,a,u),t.child;case 6:return l===null&&$&&((l=u=Hl)&&(u=wy(u,t.pendingProps,Tt),u!==null?(t.stateNode=u,Xl=t,Hl=null,l=!0):l=!1),l||Mu(t)),null;case 13:return m0(l,t,u);case 4:return _e(t,t.stateNode.containerInfo),a=t.pendingProps,l===null?t.child=Uu(t,null,a,u):Nl(l,t,a,u),t.child;case 11:return i0(l,t,t.type,t.pendingProps,u);case 7:return Nl(l,t,t.pendingProps,u),t.child;case 8:return Nl(l,t,t.pendingProps.children,u),t.child;case 12:return Nl(l,t,t.pendingProps.children,u),t.child;case 10:return a=t.pendingProps,eu(t,t.type,a.value),Nl(l,t,a.children,u),t.child;case 9:return e=t.type._context,a=t.pendingProps.children,Bu(t),e=Yl(e),a=a(e),t.flags|=1,Nl(l,t,a,u),t.child;case 14:return s0(l,t,t.type,t.pendingProps,u);case 15:return d0(l,t,t.type,t.pendingProps,u);case 19:return S0(l,t,u);case 22:return v0(l,t,u);case 24:return Bu(t),a=Yl(Ol),l===null?(e=zf(),e===null&&(e=sl,n=Tf(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=u),e=n),t.memoizedState={parent:a,cache:e},tc(t),eu(t,Ol,e)):(l.lanes&u&&(uc(l,t),te(t,null,null,u),le()),e=l.memoizedState,n=t.memoizedState,e.parent!==a?(e={parent:a,cache:a},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),eu(t,Ol,a)):(a=n.cache,eu(t,Ol,a),a!==e.cache&&lc(t,[Ol],u,!0))),Nl(l,t,t.pendingProps.children,u),t.child;case 29:throw t.pendingProps}throw Error(r(156,t.tag))}var Pf=ll(null),Yu=null,Gt=null;function eu(l,t,u){vl(Pf,t._currentValue),t._currentValue=u}function jt(l){l._currentValue=Pf.current,bl(Pf)}function If(l,t,u){for(;l!==null;){var a=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),l===u)break;l=l.return}}function lc(l,t,u,a){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var f=e.child;n=n.firstContext;l:for(;n!==null;){var c=n;n=e;for(var i=0;i<t.length;i++)if(c.context===t[i]){n.lanes|=u,c=n.alternate,c!==null&&(c.lanes|=u),If(n.return,u,l),a||(f=null);break l}n=c.next}}else if(e.tag===18){if(f=e.return,f===null)throw Error(r(341));f.lanes|=u,n=f.alternate,n!==null&&(n.lanes|=u),If(f,u,l),f=null}else f=e.child;if(f!==null)f.return=e;else for(f=e;f!==null;){if(f===l){f=null;break}if(e=f.sibling,e!==null){e.return=f.return,f=e;break}f=f.return}e=f}}function Pa(l,t,u,a){l=null;for(var e=t,n=!1;e!==null;){if(!n){if(e.flags&524288)n=!0;else if(e.flags&262144)break}if(e.tag===10){var f=e.alternate;if(f===null)throw Error(r(387));if(f=f.memoizedProps,f!==null){var c=e.type;Wl(e.pendingProps.value,f.value)||(l!==null?l.push(c):l=[c])}}else if(e===Oe.current){if(f=e.alternate,f===null)throw Error(r(387));f.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(me):l=[me])}e=e.return}l!==null&&lc(t,l,u,a),t.flags|=262144}function dn(l){for(l=l.firstContext;l!==null;){if(!Wl(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Bu(l){Yu=l,Gt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Yl(l){return E0(Yu,l)}function vn(l,t){return Yu===null&&Bu(l),E0(l,t)}function E0(l,t){var u=t._currentValue;if(t={context:t,memoizedValue:u,next:null},Gt===null){if(l===null)throw Error(r(308));Gt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Gt=Gt.next=t;return u}var nu=!1;function tc(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function uc(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function fu(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function cu(l,t,u){var a=l.updateQueue;if(a===null)return null;if(a=a.shared,ol&2){var e=a.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),a.pending=t,t=Le(l),ts(l,null,u),t}return Ve(l,a,t,u),Le(l)}function Ia(l,t,u){if(t=t.updateQueue,t!==null&&(t=t.shared,(u&4194176)!==0)){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,si(l,u)}}function ac(l,t){var u=l.updateQueue,a=l.alternate;if(a!==null&&(a=a.updateQueue,u===a)){var e=null,n=null;if(u=u.firstBaseUpdate,u!==null){do{var f={lane:u.lane,tag:u.tag,payload:u.payload,callback:null,next:null};n===null?e=n=f:n=n.next=f,u=u.next}while(u!==null);n===null?e=n=t:n=n.next=t}else e=n=t;u={baseState:a.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:a.shared,callbacks:a.callbacks},l.updateQueue=u;return}l=u.lastBaseUpdate,l===null?u.firstBaseUpdate=t:l.next=t,u.lastBaseUpdate=t}var ec=!1;function le(){if(ec){var l=fa;if(l!==null)throw l}}function te(l,t,u,a){ec=!1;var e=l.updateQueue;nu=!1;var n=e.firstBaseUpdate,f=e.lastBaseUpdate,c=e.shared.pending;if(c!==null){e.shared.pending=null;var i=c,v=i.next;i.next=null,f===null?n=v:f.next=v,f=i;var g=l.alternate;g!==null&&(g=g.updateQueue,c=g.lastBaseUpdate,c!==f&&(c===null?g.firstBaseUpdate=v:c.next=v,g.lastBaseUpdate=i))}if(n!==null){var E=e.baseState;f=0,g=v=i=null,c=n;do{var h=c.lane&-536870913,m=h!==c.lane;if(m?(J&h)===h:(a&h)===h){h!==0&&h===na&&(ec=!0),g!==null&&(g=g.next={lane:0,tag:c.tag,payload:c.payload,callback:null,next:null});l:{var M=l,B=c;h=t;var ml=u;switch(B.tag){case 1:if(M=B.payload,typeof M=="function"){E=M.call(ml,E,h);break l}E=M;break l;case 3:M.flags=M.flags&-65537|128;case 0:if(M=B.payload,h=typeof M=="function"?M.call(ml,E,h):M,h==null)break l;E=P({},E,h);break l;case 2:nu=!0}}h=c.callback,h!==null&&(l.flags|=64,m&&(l.flags|=8192),m=e.callbacks,m===null?e.callbacks=[h]:m.push(h))}else m={lane:h,tag:c.tag,payload:c.payload,callback:c.callback,next:null},g===null?(v=g=m,i=E):g=g.next=m,f|=h;if(c=c.next,c===null){if(c=e.shared.pending,c===null)break;m=c,c=m.next,m.next=null,e.lastBaseUpdate=m,e.shared.pending=null}}while(!0);g===null&&(i=E),e.baseState=i,e.firstBaseUpdate=v,e.lastBaseUpdate=g,n===null&&(e.shared.lanes=0),yu|=f,l.lanes=f,l.memoizedState=E}}function T0(l,t){if(typeof l!="function")throw Error(r(191,l));l.call(t)}function A0(l,t){var u=l.callbacks;if(u!==null)for(l.callbacks=null,l=0;l<u.length;l++)T0(u[l],t)}function ue(l,t){try{var u=t.updateQueue,a=u!==null?u.lastEffect:null;if(a!==null){var e=a.next;u=e;do{if((u.tag&l)===l){a=void 0;var n=u.create,f=u.inst;a=n(),f.destroy=a}u=u.next}while(u!==e)}}catch(c){nl(t,t.return,c)}}function iu(l,t,u){try{var a=t.updateQueue,e=a!==null?a.lastEffect:null;if(e!==null){var n=e.next;a=n;do{if((a.tag&l)===l){var f=a.inst,c=f.destroy;if(c!==void 0){f.destroy=void 0,e=t;var i=u;try{c()}catch(v){nl(e,i,v)}}}a=a.next}while(a!==n)}}catch(v){nl(t,t.return,v)}}function z0(l){var t=l.updateQueue;if(t!==null){var u=l.stateNode;try{A0(t,u)}catch(a){nl(l,l.return,a)}}}function O0(l,t,u){u.props=qu(l.type,l.memoizedProps),u.state=l.memoizedState;try{u.componentWillUnmount()}catch(a){nl(l,t,a)}}function Gu(l,t){try{var u=l.ref;if(u!==null){var a=l.stateNode;switch(l.tag){case 26:case 27:case 5:var e=a;break;default:e=a}typeof u=="function"?l.refCleanup=u(e):u.current=e}}catch(n){nl(l,t,n)}}function $l(l,t){var u=l.ref,a=l.refCleanup;if(u!==null)if(typeof a=="function")try{a()}catch(e){nl(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof u=="function")try{u(null)}catch(e){nl(l,t,e)}else u.current=null}function _0(l){var t=l.type,u=l.memoizedProps,a=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":u.autoFocus&&a.focus();break l;case"img":u.src?a.src=u.src:u.srcSet&&(a.srcset=u.srcSet)}}catch(e){nl(l,l.return,e)}}function D0(l,t,u){try{var a=l.stateNode;Zy(a,l.type,u,t),a[xl]=t}catch(e){nl(l,l.return,e)}}function M0(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27||l.tag===4}function nc(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||M0(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==27&&l.tag!==18;){if(l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function fc(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?u.nodeType===8?u.parentNode.insertBefore(l,t):u.insertBefore(l,t):(u.nodeType===8?(t=u.parentNode,t.insertBefore(l,u)):(t=u,t.appendChild(l)),u=u._reactRootContainer,u!=null||t.onclick!==null||(t.onclick=_n));else if(a!==4&&a!==27&&(l=l.child,l!==null))for(fc(l,t,u),l=l.sibling;l!==null;)fc(l,t,u),l=l.sibling}function yn(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?u.insertBefore(l,t):u.appendChild(l);else if(a!==4&&a!==27&&(l=l.child,l!==null))for(yn(l,t,u),l=l.sibling;l!==null;)yn(l,t,u),l=l.sibling}var Xt=!1,hl=!1,cc=!1,U0=typeof WeakSet=="function"?WeakSet:Set,Ul=null,R0=!1;function gy(l,t){if(l=l.containerInfo,Bc=pn,l=Ji(l),sf(l)){if("selectionStart"in l)var u={start:l.selectionStart,end:l.selectionEnd};else l:{u=(u=l.ownerDocument)&&u.defaultView||window;var a=u.getSelection&&u.getSelection();if(a&&a.rangeCount!==0){u=a.anchorNode;var e=a.anchorOffset,n=a.focusNode;a=a.focusOffset;try{u.nodeType,n.nodeType}catch{u=null;break l}var f=0,c=-1,i=-1,v=0,g=0,E=l,h=null;t:for(;;){for(var m;E!==u||e!==0&&E.nodeType!==3||(c=f+e),E!==n||a!==0&&E.nodeType!==3||(i=f+a),E.nodeType===3&&(f+=E.nodeValue.length),(m=E.firstChild)!==null;)h=E,E=m;for(;;){if(E===l)break t;if(h===u&&++v===e&&(c=f),h===n&&++g===a&&(i=f),(m=E.nextSibling)!==null)break;E=h,h=E.parentNode}E=m}u=c===-1||i===-1?null:{start:c,end:i}}else u=null}u=u||{start:0,end:0}}else u=null;for(Gc={focusedElem:l,selectionRange:u},pn=!1,Ul=t;Ul!==null;)if(t=Ul,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Ul=l;else for(;Ul!==null;){switch(t=Ul,n=t.alternate,l=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if(l&1024&&n!==null){l=void 0,u=t,e=n.memoizedProps,n=n.memoizedState,a=u.stateNode;try{var M=qu(u.type,e,u.elementType===u.type);l=a.getSnapshotBeforeUpdate(M,n),a.__reactInternalSnapshotBeforeUpdate=l}catch(B){nl(u,u.return,B)}}break;case 3:if(l&1024){if(l=t.stateNode.containerInfo,u=l.nodeType,u===9)Cc(l);else if(u===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":Cc(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if(l&1024)throw Error(r(163))}if(l=t.sibling,l!==null){l.return=t.return,Ul=l;break}Ul=t.return}return M=R0,R0=!1,M}function H0(l,t,u){var a=u.flags;switch(u.tag){case 0:case 11:case 15:Ct(l,u),a&4&&ue(5,u);break;case 1:if(Ct(l,u),a&4)if(l=u.stateNode,t===null)try{l.componentDidMount()}catch(c){nl(u,u.return,c)}else{var e=qu(u.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(c){nl(u,u.return,c)}}a&64&&z0(u),a&512&&Gu(u,u.return);break;case 3:if(Ct(l,u),a&64&&(a=u.updateQueue,a!==null)){if(l=null,u.child!==null)switch(u.child.tag){case 27:case 5:l=u.child.stateNode;break;case 1:l=u.child.stateNode}try{A0(a,l)}catch(c){nl(u,u.return,c)}}break;case 26:Ct(l,u),a&512&&Gu(u,u.return);break;case 27:case 5:Ct(l,u),t===null&&a&4&&_0(u),a&512&&Gu(u,u.return);break;case 12:Ct(l,u);break;case 13:Ct(l,u),a&4&&q0(l,u);break;case 22:if(e=u.memoizedState!==null||Xt,!e){t=t!==null&&t.memoizedState!==null||hl;var n=Xt,f=hl;Xt=e,(hl=t)&&!f?su(l,u,(u.subtreeFlags&8772)!==0):Ct(l,u),Xt=n,hl=f}a&512&&(u.memoizedProps.mode==="manual"?Gu(u,u.return):$l(u,u.return));break;default:Ct(l,u)}}function N0(l){var t=l.alternate;t!==null&&(l.alternate=null,N0(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&Jn(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var Al=null,kl=!1;function Qt(l,t,u){for(u=u.child;u!==null;)p0(l,t,u),u=u.sibling}function p0(l,t,u){if(Jl&&typeof Jl.onCommitFiberUnmount=="function")try{Jl.onCommitFiberUnmount(_a,u)}catch{}switch(u.tag){case 26:hl||$l(u,t),Qt(l,t,u),u.memoizedState?u.memoizedState.count--:u.stateNode&&(u=u.stateNode,u.parentNode.removeChild(u));break;case 27:hl||$l(u,t);var a=Al,e=kl;for(Al=u.stateNode,Qt(l,t,u),u=u.stateNode,t=u.attributes;t.length;)u.removeAttributeNode(t[0]);Jn(u),Al=a,kl=e;break;case 5:hl||$l(u,t);case 6:e=Al;var n=kl;if(Al=null,Qt(l,t,u),Al=e,kl=n,Al!==null)if(kl)try{l=Al,a=u.stateNode,l.nodeType===8?l.parentNode.removeChild(a):l.removeChild(a)}catch(f){nl(u,t,f)}else try{Al.removeChild(u.stateNode)}catch(f){nl(u,t,f)}break;case 18:Al!==null&&(kl?(t=Al,u=u.stateNode,t.nodeType===8?Qc(t.parentNode,u):t.nodeType===1&&Qc(t,u),Ee(t)):Qc(Al,u.stateNode));break;case 4:a=Al,e=kl,Al=u.stateNode.containerInfo,kl=!0,Qt(l,t,u),Al=a,kl=e;break;case 0:case 11:case 14:case 15:hl||iu(2,u,t),hl||iu(4,u,t),Qt(l,t,u);break;case 1:hl||($l(u,t),a=u.stateNode,typeof a.componentWillUnmount=="function"&&O0(u,t,a)),Qt(l,t,u);break;case 21:Qt(l,t,u);break;case 22:hl||$l(u,t),hl=(a=hl)||u.memoizedState!==null,Qt(l,t,u),hl=a;break;default:Qt(l,t,u)}}function q0(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Ee(l)}catch(u){nl(t,t.return,u)}}function Sy(l){switch(l.tag){case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new U0),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new U0),t;default:throw Error(r(435,l.tag))}}function ic(l,t){var u=Sy(l);t.forEach(function(a){var e=Ny.bind(null,l,a);u.has(a)||(u.add(a),a.then(e,e))})}function it(l,t){var u=t.deletions;if(u!==null)for(var a=0;a<u.length;a++){var e=u[a],n=l,f=t,c=f;l:for(;c!==null;){switch(c.tag){case 27:case 5:Al=c.stateNode,kl=!1;break l;case 3:Al=c.stateNode.containerInfo,kl=!0;break l;case 4:Al=c.stateNode.containerInfo,kl=!0;break l}c=c.return}if(Al===null)throw Error(r(160));p0(n,f,e),Al=null,kl=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)Y0(t,l),t=t.sibling}var mt=null;function Y0(l,t){var u=l.alternate,a=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:it(t,l),st(l),a&4&&(iu(3,l,l.return),ue(3,l),iu(5,l,l.return));break;case 1:it(t,l),st(l),a&512&&(hl||u===null||$l(u,u.return)),a&64&&Xt&&(l=l.updateQueue,l!==null&&(a=l.callbacks,a!==null&&(u=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=u===null?a:u.concat(a))));break;case 26:var e=mt;if(it(t,l),st(l),a&512&&(hl||u===null||$l(u,u.return)),a&4){var n=u!==null?u.memoizedState:null;if(a=l.memoizedState,u===null)if(a===null)if(l.stateNode===null){l:{a=l.type,u=l.memoizedProps,e=e.ownerDocument||e;t:switch(a){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Ua]||n[ql]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(a),e.head.insertBefore(n,e.querySelector("head > title"))),pl(n,a,u),n[ql]=l,Dl(n),a=n;break l;case"link":var f=_d("link","href",e).get(a+(u.href||""));if(f){for(var c=0;c<f.length;c++)if(n=f[c],n.getAttribute("href")===(u.href==null?null:u.href)&&n.getAttribute("rel")===(u.rel==null?null:u.rel)&&n.getAttribute("title")===(u.title==null?null:u.title)&&n.getAttribute("crossorigin")===(u.crossOrigin==null?null:u.crossOrigin)){f.splice(c,1);break t}}n=e.createElement(a),pl(n,a,u),e.head.appendChild(n);break;case"meta":if(f=_d("meta","content",e).get(a+(u.content||""))){for(c=0;c<f.length;c++)if(n=f[c],n.getAttribute("content")===(u.content==null?null:""+u.content)&&n.getAttribute("name")===(u.name==null?null:u.name)&&n.getAttribute("property")===(u.property==null?null:u.property)&&n.getAttribute("http-equiv")===(u.httpEquiv==null?null:u.httpEquiv)&&n.getAttribute("charset")===(u.charSet==null?null:u.charSet)){f.splice(c,1);break t}}n=e.createElement(a),pl(n,a,u),e.head.appendChild(n);break;default:throw Error(r(468,a))}n[ql]=l,Dl(n),a=n}l.stateNode=a}else Dd(e,l.type,l.stateNode);else l.stateNode=Od(e,a,l.memoizedProps);else n!==a?(n===null?u.stateNode!==null&&(u=u.stateNode,u.parentNode.removeChild(u)):n.count--,a===null?Dd(e,l.type,l.stateNode):Od(e,a,l.memoizedProps)):a===null&&l.stateNode!==null&&D0(l,l.memoizedProps,u.memoizedProps)}break;case 27:if(a&4&&l.alternate===null){e=l.stateNode,n=l.memoizedProps;try{for(var i=e.firstChild;i;){var v=i.nextSibling,g=i.nodeName;i[Ua]||g==="HEAD"||g==="BODY"||g==="SCRIPT"||g==="STYLE"||g==="LINK"&&i.rel.toLowerCase()==="stylesheet"||e.removeChild(i),i=v}for(var E=l.type,h=e.attributes;h.length;)e.removeAttributeNode(h[0]);pl(e,E,n),e[ql]=l,e[xl]=n}catch(M){nl(l,l.return,M)}}case 5:if(it(t,l),st(l),a&512&&(hl||u===null||$l(u,u.return)),l.flags&32){e=l.stateNode;try{wu(e,"")}catch(M){nl(l,l.return,M)}}a&4&&l.stateNode!=null&&(e=l.memoizedProps,D0(l,e,u!==null?u.memoizedProps:e)),a&1024&&(cc=!0);break;case 6:if(it(t,l),st(l),a&4){if(l.stateNode===null)throw Error(r(162));a=l.memoizedProps,u=l.stateNode;try{u.nodeValue=a}catch(M){nl(l,l.return,M)}}break;case 3:if(Rn=null,e=mt,mt=Mn(t.containerInfo),it(t,l),mt=e,st(l),a&4&&u!==null&&u.memoizedState.isDehydrated)try{Ee(t.containerInfo)}catch(M){nl(l,l.return,M)}cc&&(cc=!1,B0(l));break;case 4:a=mt,mt=Mn(l.stateNode.containerInfo),it(t,l),st(l),mt=a;break;case 12:it(t,l),st(l);break;case 13:it(t,l),st(l),l.child.flags&8192&&l.memoizedState!==null!=(u!==null&&u.memoizedState!==null)&&(gc=Et()),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,ic(l,a)));break;case 22:if(a&512&&(hl||u===null||$l(u,u.return)),i=l.memoizedState!==null,v=u!==null&&u.memoizedState!==null,g=Xt,E=hl,Xt=g||i,hl=E||v,it(t,l),hl=E,Xt=g,st(l),t=l.stateNode,t._current=l,t._visibility&=-3,t._visibility|=t._pendingVisibility&2,a&8192&&(t._visibility=i?t._visibility&-2:t._visibility|1,i&&(t=Xt||hl,u===null||v||t||da(l)),l.memoizedProps===null||l.memoizedProps.mode!=="manual"))l:for(u=null,t=l;;){if(t.tag===5||t.tag===26||t.tag===27){if(u===null){v=u=t;try{if(e=v.stateNode,i)n=e.style,typeof n.setProperty=="function"?n.setProperty("display","none","important"):n.display="none";else{f=v.stateNode,c=v.memoizedProps.style;var m=c!=null&&c.hasOwnProperty("display")?c.display:null;f.style.display=m==null||typeof m=="boolean"?"":(""+m).trim()}}catch(M){nl(v,v.return,M)}}}else if(t.tag===6){if(u===null){v=t;try{v.stateNode.nodeValue=i?"":v.memoizedProps}catch(M){nl(v,v.return,M)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;u===t&&(u=null),t=t.return}u===t&&(u=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=l.updateQueue,a!==null&&(u=a.retryQueue,u!==null&&(a.retryQueue=null,ic(l,u))));break;case 19:it(t,l),st(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,ic(l,a)));break;case 21:break;default:it(t,l),st(l)}}function st(l){var t=l.flags;if(t&2){try{if(l.tag!==27){l:{for(var u=l.return;u!==null;){if(M0(u)){var a=u;break l}u=u.return}throw Error(r(160))}switch(a.tag){case 27:var e=a.stateNode,n=nc(l);yn(l,n,e);break;case 5:var f=a.stateNode;a.flags&32&&(wu(f,""),a.flags&=-33);var c=nc(l);yn(l,c,f);break;case 3:case 4:var i=a.stateNode.containerInfo,v=nc(l);fc(l,v,i);break;default:throw Error(r(161))}}}catch(g){nl(l,l.return,g)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function B0(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;B0(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function Ct(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)H0(l,t.alternate,t),t=t.sibling}function da(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:iu(4,t,t.return),da(t);break;case 1:$l(t,t.return);var u=t.stateNode;typeof u.componentWillUnmount=="function"&&O0(t,t.return,u),da(t);break;case 26:case 27:case 5:$l(t,t.return),da(t);break;case 22:$l(t,t.return),t.memoizedState===null&&da(t);break;default:da(t)}l=l.sibling}}function su(l,t,u){for(u=u&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,e=l,n=t,f=n.flags;switch(n.tag){case 0:case 11:case 15:su(e,n,u),ue(4,n);break;case 1:if(su(e,n,u),a=n,e=a.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(v){nl(a,a.return,v)}if(a=n,e=a.updateQueue,e!==null){var c=a.stateNode;try{var i=e.shared.hiddenCallbacks;if(i!==null)for(e.shared.hiddenCallbacks=null,e=0;e<i.length;e++)T0(i[e],c)}catch(v){nl(a,a.return,v)}}u&&f&64&&z0(n),Gu(n,n.return);break;case 26:case 27:case 5:su(e,n,u),u&&a===null&&f&4&&_0(n),Gu(n,n.return);break;case 12:su(e,n,u);break;case 13:su(e,n,u),u&&f&4&&q0(e,n);break;case 22:n.memoizedState===null&&su(e,n,u),Gu(n,n.return);break;default:su(e,n,u)}t=t.sibling}}function sc(l,t){var u=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==u&&(l!=null&&l.refCount++,u!=null&&Ja(u))}function dc(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ja(l))}function du(l,t,u,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)G0(l,t,u,a),t=t.sibling}function G0(l,t,u,a){var e=t.flags;switch(t.tag){case 0:case 11:case 15:du(l,t,u,a),e&2048&&ue(9,t);break;case 3:du(l,t,u,a),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ja(l)));break;case 12:if(e&2048){du(l,t,u,a),l=t.stateNode;try{var n=t.memoizedProps,f=n.id,c=n.onPostCommit;typeof c=="function"&&c(f,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(i){nl(t,t.return,i)}}else du(l,t,u,a);break;case 23:break;case 22:n=t.stateNode,t.memoizedState!==null?n._visibility&4?du(l,t,u,a):ae(l,t):n._visibility&4?du(l,t,u,a):(n._visibility|=4,va(l,t,u,a,(t.subtreeFlags&10256)!==0)),e&2048&&sc(t.alternate,t);break;case 24:du(l,t,u,a),e&2048&&dc(t.alternate,t);break;default:du(l,t,u,a)}}function va(l,t,u,a,e){for(e=e&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var n=l,f=t,c=u,i=a,v=f.flags;switch(f.tag){case 0:case 11:case 15:va(n,f,c,i,e),ue(8,f);break;case 23:break;case 22:var g=f.stateNode;f.memoizedState!==null?g._visibility&4?va(n,f,c,i,e):ae(n,f):(g._visibility|=4,va(n,f,c,i,e)),e&&v&2048&&sc(f.alternate,f);break;case 24:va(n,f,c,i,e),e&&v&2048&&dc(f.alternate,f);break;default:va(n,f,c,i,e)}t=t.sibling}}function ae(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var u=l,a=t,e=a.flags;switch(a.tag){case 22:ae(u,a),e&2048&&sc(a.alternate,a);break;case 24:ae(u,a),e&2048&&dc(a.alternate,a);break;default:ae(u,a)}t=t.sibling}}var ee=8192;function ya(l){if(l.subtreeFlags&ee)for(l=l.child;l!==null;)j0(l),l=l.sibling}function j0(l){switch(l.tag){case 26:ya(l),l.flags&ee&&l.memoizedState!==null&&fo(mt,l.memoizedState,l.memoizedProps);break;case 5:ya(l);break;case 3:case 4:var t=mt;mt=Mn(l.stateNode.containerInfo),ya(l),mt=t;break;case 22:l.memoizedState===null&&(t=l.alternate,t!==null&&t.memoizedState!==null?(t=ee,ee=16777216,ya(l),ee=t):ya(l));break;default:ya(l)}}function X0(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function ne(l){var t=l.deletions;if(l.flags&16){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Ul=a,C0(a,l)}X0(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)Q0(l),l=l.sibling}function Q0(l){switch(l.tag){case 0:case 11:case 15:ne(l),l.flags&2048&&iu(9,l,l.return);break;case 3:ne(l);break;case 12:ne(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&4&&(l.return===null||l.return.tag!==13)?(t._visibility&=-5,on(l)):ne(l);break;default:ne(l)}}function on(l){var t=l.deletions;if(l.flags&16){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Ul=a,C0(a,l)}X0(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:iu(8,t,t.return),on(t);break;case 22:u=t.stateNode,u._visibility&4&&(u._visibility&=-5,on(t));break;default:on(t)}l=l.sibling}}function C0(l,t){for(;Ul!==null;){var u=Ul;switch(u.tag){case 0:case 11:case 15:iu(8,u,t);break;case 23:case 22:if(u.memoizedState!==null&&u.memoizedState.cachePool!==null){var a=u.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:Ja(u.memoizedState.cache)}if(a=u.child,a!==null)a.return=u,Ul=a;else l:for(u=l;Ul!==null;){a=Ul;var e=a.sibling,n=a.return;if(N0(a),a===u){Ul=null;break l}if(e!==null){e.return=n,Ul=e;break l}Ul=n}}}function by(l,t,u,a){this.tag=l,this.key=u,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function dt(l,t,u,a){return new by(l,t,u,a)}function vc(l){return l=l.prototype,!(!l||!l.isReactComponent)}function vu(l,t){var u=l.alternate;return u===null?(u=dt(l.tag,t,l.key,l.mode),u.elementType=l.elementType,u.type=l.type,u.stateNode=l.stateNode,u.alternate=l,l.alternate=u):(u.pendingProps=t,u.type=l.type,u.flags=0,u.subtreeFlags=0,u.deletions=null),u.flags=l.flags&31457280,u.childLanes=l.childLanes,u.lanes=l.lanes,u.child=l.child,u.memoizedProps=l.memoizedProps,u.memoizedState=l.memoizedState,u.updateQueue=l.updateQueue,t=l.dependencies,u.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},u.sibling=l.sibling,u.index=l.index,u.ref=l.ref,u.refCleanup=l.refCleanup,u}function Z0(l,t){l.flags&=31457282;var u=l.alternate;return u===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=u.childLanes,l.lanes=u.lanes,l.child=u.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=u.memoizedProps,l.memoizedState=u.memoizedState,l.updateQueue=u.updateQueue,l.type=u.type,t=u.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function hn(l,t,u,a,e,n){var f=0;if(a=l,typeof l=="function")vc(l)&&(f=1);else if(typeof l=="string")f=eo(l,u,bt.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case D:return ju(u.children,e,n,t);case b:f=8,e|=24;break;case W:return l=dt(12,u,t,e|2),l.elementType=W,l.lanes=n,l;case Il:return l=dt(13,u,t,e),l.elementType=Il,l.lanes=n,l;case Kl:return l=dt(19,u,t,e),l.elementType=Kl,l.lanes=n,l;case ot:return x0(u,e,n,t);default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case el:case cl:f=10;break l;case q:f=9;break l;case _l:f=11;break l;case Dt:f=14;break l;case Gl:f=16,a=null;break l}f=29,u=Error(r(130,l===null?"null":typeof l,"")),a=null}return t=dt(f,u,t,e),t.elementType=l,t.type=a,t.lanes=n,t}function ju(l,t,u,a){return l=dt(7,l,a,t),l.lanes=u,l}function x0(l,t,u,a){l=dt(22,l,a,t),l.elementType=ot,l.lanes=u;var e={_visibility:1,_pendingVisibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null,_current:null,detach:function(){var n=e._current;if(n===null)throw Error(r(456));if(!(e._pendingVisibility&2)){var f=It(n,2);f!==null&&(e._pendingVisibility|=2,Ql(f,n,2))}},attach:function(){var n=e._current;if(n===null)throw Error(r(456));if(e._pendingVisibility&2){var f=It(n,2);f!==null&&(e._pendingVisibility&=-3,Ql(f,n,2))}}};return l.stateNode=e,l}function yc(l,t,u){return l=dt(6,l,null,t),l.lanes=u,l}function oc(l,t,u){return t=dt(4,l.children!==null?l.children:[],l.key,t),t.lanes=u,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}function Zt(l){l.flags|=4}function V0(l,t){if(t.type!=="stylesheet"||t.state.loading&4)l.flags&=-16777217;else if(l.flags|=16777216,!Md(t)){if(t=ct.current,t!==null&&((J&4194176)===J?At!==null:(J&62914560)!==J&&!(J&536870912)||t!==At))throw Va=Sf,fs;l.flags|=8192}}function rn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?ci():536870912,l.lanes|=t,ha|=t)}function fe(l,t){if(!$)switch(l.tailMode){case"hidden":t=l.tail;for(var u=null;t!==null;)t.alternate!==null&&(u=t),t=t.sibling;u===null?l.tail=null:u.sibling=null;break;case"collapsed":u=l.tail;for(var a=null;u!==null;)u.alternate!==null&&(a=u),u=u.sibling;a===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:a.sibling=null}}function yl(l){var t=l.alternate!==null&&l.alternate.child===l.child,u=0,a=0;if(t)for(var e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags&31457280,a|=e.flags&31457280,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags,a|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=a,l.childLanes=u,t}function Ey(l,t,u){var a=t.pendingProps;switch(mf(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return yl(t),null;case 1:return yl(t),null;case 3:return u=t.stateNode,a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),jt(Ol),Zu(),u.pendingContext&&(u.context=u.pendingContext,u.pendingContext=null),(l===null||l.child===null)&&(Qa(t)?Zt(t):l===null||l.memoizedState.isDehydrated&&!(t.flags&256)||(t.flags|=1024,rt!==null&&(Tc(rt),rt=null))),yl(t),null;case 26:return u=t.memoizedState,l===null?(Zt(t),u!==null?(yl(t),V0(t,u)):(yl(t),t.flags&=-16777217)):u?u!==l.memoizedState?(Zt(t),yl(t),V0(t,u)):(yl(t),t.flags&=-16777217):(l.memoizedProps!==a&&Zt(t),yl(t),t.flags&=-16777217),null;case 27:De(t),u=$t.current;var e=t.type;if(l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Zt(t);else{if(!a){if(t.stateNode===null)throw Error(r(166));return yl(t),null}l=bt.current,Qa(t)?es(t):(l=bd(e,a,u),t.stateNode=l,Zt(t))}return yl(t),null;case 5:if(De(t),u=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Zt(t);else{if(!a){if(t.stateNode===null)throw Error(r(166));return yl(t),null}if(l=bt.current,Qa(t))es(t);else{switch(e=Dn($t.current),l){case 1:l=e.createElementNS("http://www.w3.org/2000/svg",u);break;case 2:l=e.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;default:switch(u){case"svg":l=e.createElementNS("http://www.w3.org/2000/svg",u);break;case"math":l=e.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;case"script":l=e.createElement("div"),l.innerHTML="<script><\/script>",l=l.removeChild(l.firstChild);break;case"select":l=typeof a.is=="string"?e.createElement("select",{is:a.is}):e.createElement("select"),a.multiple?l.multiple=!0:a.size&&(l.size=a.size);break;default:l=typeof a.is=="string"?e.createElement(u,{is:a.is}):e.createElement(u)}}l[ql]=t,l[xl]=a;l:for(e=t.child;e!==null;){if(e.tag===5||e.tag===6)l.appendChild(e.stateNode);else if(e.tag!==4&&e.tag!==27&&e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break l;for(;e.sibling===null;){if(e.return===null||e.return===t)break l;e=e.return}e.sibling.return=e.return,e=e.sibling}t.stateNode=l;l:switch(pl(l,u,a),u){case"button":case"input":case"select":case"textarea":l=!!a.autoFocus;break l;case"img":l=!0;break l;default:l=!1}l&&Zt(t)}}return yl(t),t.flags&=-16777217,null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==a&&Zt(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(r(166));if(l=$t.current,Qa(t)){if(l=t.stateNode,u=t.memoizedProps,a=null,e=Xl,e!==null)switch(e.tag){case 27:case 5:a=e.memoizedProps}l[ql]=t,l=!!(l.nodeValue===u||a!==null&&a.suppressHydrationWarning===!0||od(l.nodeValue,u)),l||Mu(t)}else l=Dn(l).createTextNode(a),l[ql]=t,t.stateNode=l}return yl(t),null;case 13:if(a=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=Qa(t),a!==null&&a.dehydrated!==null){if(l===null){if(!e)throw Error(r(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(317));e[ql]=t}else Ca(),!(t.flags&128)&&(t.memoizedState=null),t.flags|=4;yl(t),e=!1}else rt!==null&&(Tc(rt),rt=null),e=!0;if(!e)return t.flags&256?(qt(t),t):(qt(t),null)}if(qt(t),t.flags&128)return t.lanes=u,t;if(u=a!==null,l=l!==null&&l.memoizedState!==null,u){a=t.child,e=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(e=a.alternate.memoizedState.cachePool.pool);var n=null;a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(n=a.memoizedState.cachePool.pool),n!==e&&(a.flags|=2048)}return u!==l&&u&&(t.child.flags|=8192),rn(t,t.updateQueue),yl(t),null;case 4:return Zu(),l===null&&pc(t.stateNode.containerInfo),yl(t),null;case 10:return jt(t.type),yl(t),null;case 19:if(bl(zl),e=t.memoizedState,e===null)return yl(t),null;if(a=(t.flags&128)!==0,n=e.rendering,n===null)if(a)fe(e,!1);else{if(rl!==0||l!==null&&l.flags&128)for(l=t.child;l!==null;){if(n=Fe(l),n!==null){for(t.flags|=128,fe(e,!1),l=n.updateQueue,t.updateQueue=l,rn(t,l),t.subtreeFlags=0,l=u,u=t.child;u!==null;)Z0(u,l),u=u.sibling;return vl(zl,zl.current&1|2),t.child}l=l.sibling}e.tail!==null&&Et()>mn&&(t.flags|=128,a=!0,fe(e,!1),t.lanes=4194304)}else{if(!a)if(l=Fe(n),l!==null){if(t.flags|=128,a=!0,l=l.updateQueue,t.updateQueue=l,rn(t,l),fe(e,!0),e.tail===null&&e.tailMode==="hidden"&&!n.alternate&&!$)return yl(t),null}else 2*Et()-e.renderingStartTime>mn&&u!==536870912&&(t.flags|=128,a=!0,fe(e,!1),t.lanes=4194304);e.isBackwards?(n.sibling=t.child,t.child=n):(l=e.last,l!==null?l.sibling=n:t.child=n,e.last=n)}return e.tail!==null?(t=e.tail,e.rendering=t,e.tail=t.sibling,e.renderingStartTime=Et(),t.sibling=null,l=zl.current,vl(zl,a?l&1|2:l&1),t):(yl(t),null);case 22:case 23:return qt(t),Ef(),a=t.memoizedState!==null,l!==null?l.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?u&536870912&&!(t.flags&128)&&(yl(t),t.subtreeFlags&6&&(t.flags|=8192)):yl(t),u=t.updateQueue,u!==null&&rn(t,u.retryQueue),u=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==u&&(t.flags|=2048),l!==null&&bl(Ru),null;case 24:return u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),jt(Ol),yl(t),null;case 25:return null}throw Error(r(156,t.tag))}function Ty(l,t){switch(mf(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return jt(Ol),Zu(),l=t.flags,l&65536&&!(l&128)?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return De(t),null;case 13:if(qt(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(r(340));Ca()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return bl(zl),null;case 4:return Zu(),null;case 10:return jt(t.type),null;case 22:case 23:return qt(t),Ef(),l!==null&&bl(Ru),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return jt(Ol),null;case 25:return null;default:return null}}function L0(l,t){switch(mf(t),t.tag){case 3:jt(Ol),Zu();break;case 26:case 27:case 5:De(t);break;case 4:Zu();break;case 13:qt(t);break;case 19:bl(zl);break;case 10:jt(t.type);break;case 22:case 23:qt(t),Ef(),l!==null&&bl(Ru);break;case 24:jt(Ol)}}var Ay={getCacheForType:function(l){var t=Yl(Ol),u=t.data.get(l);return u===void 0&&(u=l(),t.data.set(l,u)),u}},zy=typeof WeakMap=="function"?WeakMap:Map,ol=0,sl=null,x=null,J=0,dl=0,Fl=null,xt=!1,oa=!1,hc=!1,Vt=0,rl=0,yu=0,Xu=0,rc=0,vt=0,ha=0,ce=null,Ot=null,mc=!1,gc=0,mn=1/0,gn=null,ou=null,Sn=!1,Qu=null,ie=0,Sc=0,bc=null,se=0,Ec=null;function Pl(){if(ol&2&&J!==0)return J&-J;if(N.T!==null){var l=na;return l!==0?l:Uc()}return vi()}function K0(){vt===0&&(vt=!(J&536870912)||$?fi():536870912);var l=ct.current;return l!==null&&(l.flags|=32),vt}function Ql(l,t,u){(l===sl&&dl===2||l.cancelPendingCommit!==null)&&(ra(l,0),Lt(l,J,vt,!1)),Ma(l,u),(!(ol&2)||l!==sl)&&(l===sl&&(!(ol&2)&&(Xu|=u),rl===4&&Lt(l,J,vt,!1)),_t(l))}function J0(l,t,u){if(ol&6)throw Error(r(327));var a=!u&&(t&60)===0&&(t&l.expiredLanes)===0||Da(l,t),e=a?Dy(l,t):Oc(l,t,!0),n=a;do{if(e===0){oa&&!a&&Lt(l,t,0,!1);break}else if(e===6)Lt(l,t,0,!xt);else{if(u=l.current.alternate,n&&!Oy(u)){e=Oc(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var f=0;else f=l.pendingLanes&-536870913,f=f!==0?f:f&536870912?536870912:0;if(f!==0){t=f;l:{var c=l;e=ce;var i=c.current.memoizedState.isDehydrated;if(i&&(ra(c,f).flags|=256),f=Oc(c,f,!1),f!==2){if(hc&&!i){c.errorRecoveryDisabledLanes|=n,Xu|=n,e=4;break l}n=Ot,Ot=e,n!==null&&Tc(n)}e=f}if(n=!1,e!==2)continue}}if(e===1){ra(l,0),Lt(l,t,0,!0);break}l:{switch(a=l,e){case 0:case 1:throw Error(r(345));case 4:if((t&4194176)===t){Lt(a,t,vt,!xt);break l}break;case 2:Ot=null;break;case 3:case 5:break;default:throw Error(r(329))}if(a.finishedWork=u,a.finishedLanes=t,(t&62914560)===t&&(n=gc+300-Et(),10<n)){if(Lt(a,t,vt,!xt),He(a,0)!==0)break l;a.timeoutHandle=md(w0.bind(null,a,u,Ot,gn,mc,t,vt,Xu,ha,xt,2,-0,0),n);break l}w0(a,u,Ot,gn,mc,t,vt,Xu,ha,xt,0,-0,0)}}break}while(!0);_t(l)}function Tc(l){Ot===null?Ot=l:Ot.push.apply(Ot,l)}function w0(l,t,u,a,e,n,f,c,i,v,g,E,h){var m=t.subtreeFlags;if((m&8192||(m&16785408)===16785408)&&(re={stylesheets:null,count:0,unsuspend:no},j0(t),t=co(),t!==null)){l.cancelPendingCommit=t(ld.bind(null,l,u,a,e,f,c,i,1,E,h)),Lt(l,n,f,!v);return}ld(l,u,a,e,f,c,i,g,E,h)}function Oy(l){for(var t=l;;){var u=t.tag;if((u===0||u===11||u===15)&&t.flags&16384&&(u=t.updateQueue,u!==null&&(u=u.stores,u!==null)))for(var a=0;a<u.length;a++){var e=u[a],n=e.getSnapshot;e=e.value;try{if(!Wl(n(),e))return!1}catch{return!1}}if(u=t.child,t.subtreeFlags&16384&&u!==null)u.return=t,t=u;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function Lt(l,t,u,a){t&=~rc,t&=~Xu,l.suspendedLanes|=t,l.pingedLanes&=~t,a&&(l.warmLanes|=t),a=l.expirationTimes;for(var e=t;0<e;){var n=31-wl(e),f=1<<n;a[n]=-1,e&=~f}u!==0&&ii(l,u,t)}function bn(){return ol&6?!0:(de(0),!1)}function Ac(){if(x!==null){if(dl===0)var l=x.return;else l=x,Gt=Yu=null,Uf(l),aa=null,La=0,l=x;for(;l!==null;)L0(l.alternate,l),l=l.return;x=null}}function ra(l,t){l.finishedWork=null,l.finishedLanes=0;var u=l.timeoutHandle;u!==-1&&(l.timeoutHandle=-1,Vy(u)),u=l.cancelPendingCommit,u!==null&&(l.cancelPendingCommit=null,u()),Ac(),sl=l,x=u=vu(l.current,null),J=t,dl=0,Fl=null,xt=!1,oa=Da(l,t),hc=!1,ha=vt=rc=Xu=yu=rl=0,Ot=ce=null,mc=!1,t&8&&(t|=t&32);var a=l.entangledLanes;if(a!==0)for(l=l.entanglements,a&=t;0<a;){var e=31-wl(a),n=1<<e;t|=l[e],a&=~n}return Vt=t,xe(),u}function W0(l,t){C=null,N.H=zt,t===xa?(t=ss(),dl=3):t===fs?(t=ss(),dl=4):dl=t===c0?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,Fl=t,x===null&&(rl=1,sn(l,et(t,l.current)))}function $0(){var l=N.H;return N.H=zt,l===null?zt:l}function k0(){var l=N.A;return N.A=Ay,l}function zc(){rl=4,xt||(J&4194176)!==J&&ct.current!==null||(oa=!0),!(yu&134217727)&&!(Xu&134217727)||sl===null||Lt(sl,J,vt,!1)}function Oc(l,t,u){var a=ol;ol|=2;var e=$0(),n=k0();(sl!==l||J!==t)&&(gn=null,ra(l,t)),t=!1;var f=rl;l:do try{if(dl!==0&&x!==null){var c=x,i=Fl;switch(dl){case 8:Ac(),f=6;break l;case 3:case 2:case 6:ct.current===null&&(t=!0);var v=dl;if(dl=0,Fl=null,ma(l,c,i,v),u&&oa){f=0;break l}break;default:v=dl,dl=0,Fl=null,ma(l,c,i,v)}}_y(),f=rl;break}catch(g){W0(l,g)}while(!0);return t&&l.shellSuspendCounter++,Gt=Yu=null,ol=a,N.H=e,N.A=n,x===null&&(sl=null,J=0,xe()),f}function _y(){for(;x!==null;)F0(x)}function Dy(l,t){var u=ol;ol|=2;var a=$0(),e=k0();sl!==l||J!==t?(gn=null,mn=Et()+500,ra(l,t)):oa=Da(l,t);l:do try{if(dl!==0&&x!==null){t=x;var n=Fl;t:switch(dl){case 1:dl=0,Fl=null,ma(l,t,n,1);break;case 2:if(cs(n)){dl=0,Fl=null,P0(t);break}t=function(){dl===2&&sl===l&&(dl=7),_t(l)},n.then(t,t);break l;case 3:dl=7;break l;case 4:dl=5;break l;case 7:cs(n)?(dl=0,Fl=null,P0(t)):(dl=0,Fl=null,ma(l,t,n,7));break;case 5:var f=null;switch(x.tag){case 26:f=x.memoizedState;case 5:case 27:var c=x;if(!f||Md(f)){dl=0,Fl=null;var i=c.sibling;if(i!==null)x=i;else{var v=c.return;v!==null?(x=v,En(v)):x=null}break t}}dl=0,Fl=null,ma(l,t,n,5);break;case 6:dl=0,Fl=null,ma(l,t,n,6);break;case 8:Ac(),rl=6;break l;default:throw Error(r(462))}}My();break}catch(g){W0(l,g)}while(!0);return Gt=Yu=null,N.H=a,N.A=e,ol=u,x!==null?0:(sl=null,J=0,xe(),rl)}function My(){for(;x!==null&&!$d();)F0(x)}function F0(l){var t=b0(l.alternate,l,Vt);l.memoizedProps=l.pendingProps,t===null?En(l):x=t}function P0(l){var t=l,u=t.alternate;switch(t.tag){case 15:case 0:t=o0(u,t,t.pendingProps,t.type,void 0,J);break;case 11:t=o0(u,t,t.pendingProps,t.type.render,t.ref,J);break;case 5:Uf(t);default:L0(u,t),t=x=Z0(t,Vt),t=b0(u,t,Vt)}l.memoizedProps=l.pendingProps,t===null?En(l):x=t}function ma(l,t,u,a){Gt=Yu=null,Uf(t),aa=null,La=0;var e=t.return;try{if(ry(l,e,t,u,J)){rl=1,sn(l,et(u,l.current)),x=null;return}}catch(n){if(e!==null)throw x=e,n;rl=1,sn(l,et(u,l.current)),x=null;return}t.flags&32768?($||a===1?l=!0:oa||J&536870912?l=!1:(xt=l=!0,(a===2||a===3||a===6)&&(a=ct.current,a!==null&&a.tag===13&&(a.flags|=16384))),I0(t,l)):En(t)}function En(l){var t=l;do{if(t.flags&32768){I0(t,xt);return}l=t.return;var u=Ey(t.alternate,t,Vt);if(u!==null){x=u;return}if(t=t.sibling,t!==null){x=t;return}x=t=l}while(t!==null);rl===0&&(rl=5)}function I0(l,t){do{var u=Ty(l.alternate,l);if(u!==null){u.flags&=32767,x=u;return}if(u=l.return,u!==null&&(u.flags|=32768,u.subtreeFlags=0,u.deletions=null),!t&&(l=l.sibling,l!==null)){x=l;return}x=l=u}while(l!==null);rl=6,x=null}function ld(l,t,u,a,e,n,f,c,i,v){var g=N.T,E=O.p;try{O.p=2,N.T=null,Uy(l,t,u,a,E,e,n,f,c,i,v)}finally{N.T=g,O.p=E}}function Uy(l,t,u,a,e,n,f,c){do ga();while(Qu!==null);if(ol&6)throw Error(r(327));var i=l.finishedWork;if(a=l.finishedLanes,i===null)return null;if(l.finishedWork=null,l.finishedLanes=0,i===l.current)throw Error(r(177));l.callbackNode=null,l.callbackPriority=0,l.cancelPendingCommit=null;var v=i.lanes|i.childLanes;if(v|=of,fv(l,a,v,n,f,c),l===sl&&(x=sl=null,J=0),!(i.subtreeFlags&10256)&&!(i.flags&10256)||Sn||(Sn=!0,Sc=v,bc=u,py(Me,function(){return ga(),null})),u=(i.flags&15990)!==0,i.subtreeFlags&15990||u?(u=N.T,N.T=null,n=O.p,O.p=2,f=ol,ol|=4,gy(l,i),Y0(i,l),Pv(Gc,l.containerInfo),pn=!!Bc,Gc=Bc=null,l.current=i,H0(l,i.alternate,i),kd(),ol=f,O.p=n,N.T=u):l.current=i,Sn?(Sn=!1,Qu=l,ie=a):td(l,v),v=l.pendingLanes,v===0&&(ou=null),tv(i.stateNode),_t(l),t!==null)for(e=l.onRecoverableError,i=0;i<t.length;i++)v=t[i],e(v.value,{componentStack:v.stack});return ie&3&&ga(),v=l.pendingLanes,a&4194218&&v&42?l===Ec?se++:(se=0,Ec=l):se=0,de(0),null}function td(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,Ja(t)))}function ga(){if(Qu!==null){var l=Qu,t=Sc;Sc=0;var u=di(ie),a=N.T,e=O.p;try{if(O.p=32>u?32:u,N.T=null,Qu===null)var n=!1;else{u=bc,bc=null;var f=Qu,c=ie;if(Qu=null,ie=0,ol&6)throw Error(r(331));var i=ol;if(ol|=4,Q0(f.current),G0(f,f.current,c,u),ol=i,de(0,!1),Jl&&typeof Jl.onPostCommitFiberRoot=="function")try{Jl.onPostCommitFiberRoot(_a,f)}catch{}n=!0}return n}finally{O.p=e,N.T=a,td(l,t)}}return!1}function ud(l,t,u){t=et(u,t),t=xf(l.stateNode,t,2),l=cu(l,t,2),l!==null&&(Ma(l,2),_t(l))}function nl(l,t,u){if(l.tag===3)ud(l,l,u);else for(;t!==null;){if(t.tag===3){ud(t,l,u);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(ou===null||!ou.has(a))){l=et(u,l),u=n0(2),a=cu(t,u,2),a!==null&&(f0(u,a,t,l),Ma(a,2),_t(a));break}}t=t.return}}function _c(l,t,u){var a=l.pingCache;if(a===null){a=l.pingCache=new zy;var e=new Set;a.set(t,e)}else e=a.get(t),e===void 0&&(e=new Set,a.set(t,e));e.has(u)||(hc=!0,e.add(u),l=Ry.bind(null,l,t,u),t.then(l,l))}function Ry(l,t,u){var a=l.pingCache;a!==null&&a.delete(t),l.pingedLanes|=l.suspendedLanes&u,l.warmLanes&=~u,sl===l&&(J&u)===u&&(rl===4||rl===3&&(J&62914560)===J&&300>Et()-gc?!(ol&2)&&ra(l,0):rc|=u,ha===J&&(ha=0)),_t(l)}function ad(l,t){t===0&&(t=ci()),l=It(l,t),l!==null&&(Ma(l,t),_t(l))}function Hy(l){var t=l.memoizedState,u=0;t!==null&&(u=t.retryLane),ad(l,u)}function Ny(l,t){var u=0;switch(l.tag){case 13:var a=l.stateNode,e=l.memoizedState;e!==null&&(u=e.retryLane);break;case 19:a=l.stateNode;break;case 22:a=l.stateNode._retryCache;break;default:throw Error(r(314))}a!==null&&a.delete(t),ad(l,u)}function py(l,t){return xn(l,t)}var Tn=null,Sa=null,Dc=!1,An=!1,Mc=!1,Cu=0;function _t(l){l!==Sa&&l.next===null&&(Sa===null?Tn=Sa=l:Sa=Sa.next=l),An=!0,Dc||(Dc=!0,Yy(qy))}function de(l,t){if(!Mc&&An){Mc=!0;do for(var u=!1,a=Tn;a!==null;){if(l!==0){var e=a.pendingLanes;if(e===0)var n=0;else{var f=a.suspendedLanes,c=a.pingedLanes;n=(1<<31-wl(42|l)+1)-1,n&=e&~(f&~c),n=n&201326677?n&201326677|1:n?n|2:0}n!==0&&(u=!0,fd(a,n))}else n=J,n=He(a,a===sl?n:0),!(n&3)||Da(a,n)||(u=!0,fd(a,n));a=a.next}while(u);Mc=!1}}function qy(){An=Dc=!1;var l=0;Cu!==0&&(xy()&&(l=Cu),Cu=0);for(var t=Et(),u=null,a=Tn;a!==null;){var e=a.next,n=ed(a,t);n===0?(a.next=null,u===null?Tn=e:u.next=e,e===null&&(Sa=u)):(u=a,(l!==0||n&3)&&(An=!0)),a=e}de(l)}function ed(l,t){for(var u=l.suspendedLanes,a=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var f=31-wl(n),c=1<<f,i=e[f];i===-1?(!(c&u)||c&a)&&(e[f]=nv(c,t)):i<=t&&(l.expiredLanes|=c),n&=~c}if(t=sl,u=J,u=He(l,l===t?u:0),a=l.callbackNode,u===0||l===t&&dl===2||l.cancelPendingCommit!==null)return a!==null&&a!==null&&Vn(a),l.callbackNode=null,l.callbackPriority=0;if(!(u&3)||Da(l,u)){if(t=u&-u,t===l.callbackPriority)return t;switch(a!==null&&Vn(a),di(u)){case 2:case 8:u=ei;break;case 32:u=Me;break;case 268435456:u=ni;break;default:u=Me}return a=nd.bind(null,l),u=xn(u,a),l.callbackPriority=t,l.callbackNode=u,t}return a!==null&&a!==null&&Vn(a),l.callbackPriority=2,l.callbackNode=null,2}function nd(l,t){var u=l.callbackNode;if(ga()&&l.callbackNode!==u)return null;var a=J;return a=He(l,l===sl?a:0),a===0?null:(J0(l,a,t),ed(l,Et()),l.callbackNode!=null&&l.callbackNode===u?nd.bind(null,l):null)}function fd(l,t){if(ga())return null;J0(l,t,!0)}function Yy(l){Ly(function(){ol&6?xn(ai,l):l()})}function Uc(){return Cu===0&&(Cu=fi()),Cu}function cd(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Be(""+l)}function id(l,t){var u=t.ownerDocument.createElement("input");return u.name=t.name,u.value=t.value,l.id&&u.setAttribute("form",l.id),t.parentNode.insertBefore(u,t),l=new FormData(l),u.parentNode.removeChild(u),l}function By(l,t,u,a,e){if(t==="submit"&&u&&u.stateNode===e){var n=cd((e[xl]||null).action),f=a.submitter;f&&(t=(t=f[xl]||null)?cd(t.formAction):f.getAttribute("formAction"),t!==null&&(n=t,f=null));var c=new Qe("action","action",null,a,e);l.push({event:c,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(Cu!==0){var i=f?id(e,f):new FormData(e);jf(u,{pending:!0,data:i,method:e.method,action:n},null,i)}}else typeof n=="function"&&(c.preventDefault(),i=f?id(e,f):new FormData(e),jf(u,{pending:!0,data:i,method:e.method,action:n},n,i))},currentTarget:e}]})}}for(var Rc=0;Rc<ls.length;Rc++){var Hc=ls[Rc],Gy=Hc.toLowerCase(),jy=Hc[0].toUpperCase()+Hc.slice(1);ht(Gy,"on"+jy)}ht($i,"onAnimationEnd"),ht(ki,"onAnimationIteration"),ht(Fi,"onAnimationStart"),ht("dblclick","onDoubleClick"),ht("focusin","onFocus"),ht("focusout","onBlur"),ht(ly,"onTransitionRun"),ht(ty,"onTransitionStart"),ht(uy,"onTransitionCancel"),ht(Pi,"onTransitionEnd"),Ku("onMouseEnter",["mouseout","mouseover"]),Ku("onMouseLeave",["mouseout","mouseover"]),Ku("onPointerEnter",["pointerout","pointerover"]),Ku("onPointerLeave",["pointerout","pointerover"]),Tu("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Tu("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Tu("onBeforeInput",["compositionend","keypress","textInput","paste"]),Tu("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Tu("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Tu("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var ve="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Xy=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(ve));function sd(l,t){t=(t&4)!==0;for(var u=0;u<l.length;u++){var a=l[u],e=a.event;a=a.listeners;l:{var n=void 0;if(t)for(var f=a.length-1;0<=f;f--){var c=a[f],i=c.instance,v=c.currentTarget;if(c=c.listener,i!==n&&e.isPropagationStopped())break l;n=c,e.currentTarget=v;try{n(e)}catch(g){cn(g)}e.currentTarget=null,n=i}else for(f=0;f<a.length;f++){if(c=a[f],i=c.instance,v=c.currentTarget,c=c.listener,i!==n&&e.isPropagationStopped())break l;n=c,e.currentTarget=v;try{n(e)}catch(g){cn(g)}e.currentTarget=null,n=i}}}}function L(l,t){var u=t[Kn];u===void 0&&(u=t[Kn]=new Set);var a=l+"__bubble";u.has(a)||(dd(t,l,2,!1),u.add(a))}function Nc(l,t,u){var a=0;t&&(a|=4),dd(u,l,a,t)}var zn="_reactListening"+Math.random().toString(36).slice(2);function pc(l){if(!l[zn]){l[zn]=!0,oi.forEach(function(u){u!=="selectionchange"&&(Xy.has(u)||Nc(u,!1,l),Nc(u,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[zn]||(t[zn]=!0,Nc("selectionchange",!1,t))}}function dd(l,t,u,a){switch(qd(t)){case 2:var e=vo;break;case 8:e=yo;break;default:e=Kc}u=e.bind(null,t,u,l),e=void 0,!In||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),a?e!==void 0?l.addEventListener(t,u,{capture:!0,passive:e}):l.addEventListener(t,u,!0):e!==void 0?l.addEventListener(t,u,{passive:e}):l.addEventListener(t,u,!1)}function qc(l,t,u,a,e){var n=a;if(!(t&1)&&!(t&2)&&a!==null)l:for(;;){if(a===null)return;var f=a.tag;if(f===3||f===4){var c=a.stateNode.containerInfo;if(c===e||c.nodeType===8&&c.parentNode===e)break;if(f===4)for(f=a.return;f!==null;){var i=f.tag;if((i===3||i===4)&&(i=f.stateNode.containerInfo,i===e||i.nodeType===8&&i.parentNode===e))return;f=f.return}for(;c!==null;){if(f=Eu(c),f===null)return;if(i=f.tag,i===5||i===6||i===26||i===27){a=n=f;continue l}c=c.parentNode}}a=a.return}_i(function(){var v=n,g=Fn(u),E=[];l:{var h=Ii.get(l);if(h!==void 0){var m=Qe,M=l;switch(l){case"keypress":if(je(u)===0)break l;case"keydown":case"keyup":m=Nv;break;case"focusin":M="focus",m=af;break;case"focusout":M="blur",m=af;break;case"beforeblur":case"afterblur":m=af;break;case"click":if(u.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":m=Ui;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":m=bv;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":m=Yv;break;case $i:case ki:case Fi:m=Av;break;case Pi:m=Gv;break;case"scroll":case"scrollend":m=gv;break;case"wheel":m=Xv;break;case"copy":case"cut":case"paste":m=Ov;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":m=Hi;break;case"toggle":case"beforetoggle":m=Cv}var B=(t&4)!==0,ml=!B&&(l==="scroll"||l==="scrollend"),y=B?h!==null?h+"Capture":null:h;B=[];for(var d=v,o;d!==null;){var S=d;if(o=S.stateNode,S=S.tag,S!==5&&S!==26&&S!==27||o===null||y===null||(S=Ha(d,y),S!=null&&B.push(ye(d,S,o))),ml)break;d=d.return}0<B.length&&(h=new m(h,M,null,u,g),E.push({event:h,listeners:B}))}}if(!(t&7)){l:{if(h=l==="mouseover"||l==="pointerover",m=l==="mouseout"||l==="pointerout",h&&u!==kn&&(M=u.relatedTarget||u.fromElement)&&(Eu(M)||M[xu]))break l;if((m||h)&&(h=g.window===g?g:(h=g.ownerDocument)?h.defaultView||h.parentWindow:window,m?(M=u.relatedTarget||u.toElement,m=v,M=M?Eu(M):null,M!==null&&(ml=Y(M),B=M.tag,M!==ml||B!==5&&B!==27&&B!==6)&&(M=null)):(m=null,M=v),m!==M)){if(B=Ui,S="onMouseLeave",y="onMouseEnter",d="mouse",(l==="pointerout"||l==="pointerover")&&(B=Hi,S="onPointerLeave",y="onPointerEnter",d="pointer"),ml=m==null?h:Ra(m),o=M==null?h:Ra(M),h=new B(S,d+"leave",m,u,g),h.target=ml,h.relatedTarget=o,S=null,Eu(g)===v&&(B=new B(y,d+"enter",M,u,g),B.target=o,B.relatedTarget=ml,S=B),ml=S,m&&M)t:{for(B=m,y=M,d=0,o=B;o;o=ba(o))d++;for(o=0,S=y;S;S=ba(S))o++;for(;0<d-o;)B=ba(B),d--;for(;0<o-d;)y=ba(y),o--;for(;d--;){if(B===y||y!==null&&B===y.alternate)break t;B=ba(B),y=ba(y)}B=null}else B=null;m!==null&&vd(E,h,m,B,!1),M!==null&&ml!==null&&vd(E,ml,M,B,!0)}}l:{if(h=v?Ra(v):window,m=h.nodeName&&h.nodeName.toLowerCase(),m==="select"||m==="input"&&h.type==="file")var _=Xi;else if(Gi(h))if(Qi)_=kv;else{_=Wv;var Z=wv}else m=h.nodeName,!m||m.toLowerCase()!=="input"||h.type!=="checkbox"&&h.type!=="radio"?v&&$n(v.elementType)&&(_=Xi):_=$v;if(_&&(_=_(l,v))){ji(E,_,u,g);break l}Z&&Z(l,h,v),l==="focusout"&&v&&h.type==="number"&&v.memoizedProps.value!=null&&Wn(h,"number",h.value)}switch(Z=v?Ra(v):window,l){case"focusin":(Gi(Z)||Z.contentEditable==="true")&&(Fu=Z,df=v,Xa=null);break;case"focusout":Xa=df=Fu=null;break;case"mousedown":vf=!0;break;case"contextmenu":case"mouseup":case"dragend":vf=!1,wi(E,u,g);break;case"selectionchange":if(Iv)break;case"keydown":case"keyup":wi(E,u,g)}var U;if(nf)l:{switch(l){case"compositionstart":var H="onCompositionStart";break l;case"compositionend":H="onCompositionEnd";break l;case"compositionupdate":H="onCompositionUpdate";break l}H=void 0}else ku?Yi(l,u)&&(H="onCompositionEnd"):l==="keydown"&&u.keyCode===229&&(H="onCompositionStart");H&&(Ni&&u.locale!=="ko"&&(ku||H!=="onCompositionStart"?H==="onCompositionEnd"&&ku&&(U=Di()):(Pt=g,lf="value"in Pt?Pt.value:Pt.textContent,ku=!0)),Z=On(v,H),0<Z.length&&(H=new Ri(H,l,null,u,g),E.push({event:H,listeners:Z}),U?H.data=U:(U=Bi(u),U!==null&&(H.data=U)))),(U=xv?Vv(l,u):Lv(l,u))&&(H=On(v,"onBeforeInput"),0<H.length&&(Z=new Ri("onBeforeInput","beforeinput",null,u,g),E.push({event:Z,listeners:H}),Z.data=U)),By(E,l,v,u,g)}sd(E,t)})}function ye(l,t,u){return{instance:l,listener:t,currentTarget:u}}function On(l,t){for(var u=t+"Capture",a=[];l!==null;){var e=l,n=e.stateNode;e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=Ha(l,u),e!=null&&a.unshift(ye(l,e,n)),e=Ha(l,t),e!=null&&a.push(ye(l,e,n))),l=l.return}return a}function ba(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function vd(l,t,u,a,e){for(var n=t._reactName,f=[];u!==null&&u!==a;){var c=u,i=c.alternate,v=c.stateNode;if(c=c.tag,i!==null&&i===a)break;c!==5&&c!==26&&c!==27||v===null||(i=v,e?(v=Ha(u,n),v!=null&&f.unshift(ye(u,v,i))):e||(v=Ha(u,n),v!=null&&f.push(ye(u,v,i)))),u=u.return}f.length!==0&&l.push({event:t,listeners:f})}var Qy=/\r\n?/g,Cy=/\u0000|\uFFFD/g;function yd(l){return(typeof l=="string"?l:""+l).replace(Qy,`
`).replace(Cy,"")}function od(l,t){return t=yd(t),yd(l)===t}function _n(){}function ul(l,t,u,a,e,n){switch(u){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||wu(l,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&wu(l,""+a);break;case"className":pe(l,"class",a);break;case"tabIndex":pe(l,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":pe(l,u,a);break;case"style":zi(l,a,n);break;case"data":if(t!=="object"){pe(l,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||u!=="href")){l.removeAttribute(u);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=Be(""+a),l.setAttribute(u,a);break;case"action":case"formAction":if(typeof a=="function"){l.setAttribute(u,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(u==="formAction"?(t!=="input"&&ul(l,t,"name",e.name,e,null),ul(l,t,"formEncType",e.formEncType,e,null),ul(l,t,"formMethod",e.formMethod,e,null),ul(l,t,"formTarget",e.formTarget,e,null)):(ul(l,t,"encType",e.encType,e,null),ul(l,t,"method",e.method,e,null),ul(l,t,"target",e.target,e,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=Be(""+a),l.setAttribute(u,a);break;case"onClick":a!=null&&(l.onclick=_n);break;case"onScroll":a!=null&&L("scroll",l);break;case"onScrollEnd":a!=null&&L("scrollend",l);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(r(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(r(60));l.innerHTML=u}}break;case"multiple":l.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":l.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){l.removeAttribute("xlink:href");break}u=Be(""+a),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",u);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""+a):l.removeAttribute(u);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""):l.removeAttribute(u);break;case"capture":case"download":a===!0?l.setAttribute(u,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,a):l.removeAttribute(u);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?l.setAttribute(u,a):l.removeAttribute(u);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?l.removeAttribute(u):l.setAttribute(u,a);break;case"popover":L("beforetoggle",l),L("toggle",l),Ne(l,"popover",a);break;case"xlinkActuate":Ht(l,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Ht(l,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Ht(l,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Ht(l,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Ht(l,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Ht(l,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Ht(l,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Ht(l,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Ht(l,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":Ne(l,"is",a);break;case"innerText":case"textContent":break;default:(!(2<u.length)||u[0]!=="o"&&u[0]!=="O"||u[1]!=="n"&&u[1]!=="N")&&(u=rv.get(u)||u,Ne(l,u,a))}}function Yc(l,t,u,a,e,n){switch(u){case"style":zi(l,a,n);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(r(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(r(60));l.innerHTML=u}}break;case"children":typeof a=="string"?wu(l,a):(typeof a=="number"||typeof a=="bigint")&&wu(l,""+a);break;case"onScroll":a!=null&&L("scroll",l);break;case"onScrollEnd":a!=null&&L("scrollend",l);break;case"onClick":a!=null&&(l.onclick=_n);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!hi.hasOwnProperty(u))l:{if(u[0]==="o"&&u[1]==="n"&&(e=u.endsWith("Capture"),t=u.slice(2,e?u.length-7:void 0),n=l[xl]||null,n=n!=null?n[u]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof a=="function")){typeof n!="function"&&n!==null&&(u in l?l[u]=null:l.hasAttribute(u)&&l.removeAttribute(u)),l.addEventListener(t,a,e);break l}u in l?l[u]=a:a===!0?l.setAttribute(u,""):Ne(l,u,a)}}}function pl(l,t,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":L("error",l),L("load",l);var a=!1,e=!1,n;for(n in u)if(u.hasOwnProperty(n)){var f=u[n];if(f!=null)switch(n){case"src":a=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,t));default:ul(l,t,n,f,u,null)}}e&&ul(l,t,"srcSet",u.srcSet,u,null),a&&ul(l,t,"src",u.src,u,null);return;case"input":L("invalid",l);var c=n=f=e=null,i=null,v=null;for(a in u)if(u.hasOwnProperty(a)){var g=u[a];if(g!=null)switch(a){case"name":e=g;break;case"type":f=g;break;case"checked":i=g;break;case"defaultChecked":v=g;break;case"value":n=g;break;case"defaultValue":c=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(r(137,t));break;default:ul(l,t,a,g,u,null)}}bi(l,n,c,i,v,f,e,!1),qe(l);return;case"select":L("invalid",l),a=f=n=null;for(e in u)if(u.hasOwnProperty(e)&&(c=u[e],c!=null))switch(e){case"value":n=c;break;case"defaultValue":f=c;break;case"multiple":a=c;default:ul(l,t,e,c,u,null)}t=n,u=f,l.multiple=!!a,t!=null?Ju(l,!!a,t,!1):u!=null&&Ju(l,!!a,u,!0);return;case"textarea":L("invalid",l),n=e=a=null;for(f in u)if(u.hasOwnProperty(f)&&(c=u[f],c!=null))switch(f){case"value":a=c;break;case"defaultValue":e=c;break;case"children":n=c;break;case"dangerouslySetInnerHTML":if(c!=null)throw Error(r(91));break;default:ul(l,t,f,c,u,null)}Ti(l,a,e,n),qe(l);return;case"option":for(i in u)if(u.hasOwnProperty(i)&&(a=u[i],a!=null))switch(i){case"selected":l.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:ul(l,t,i,a,u,null)}return;case"dialog":L("cancel",l),L("close",l);break;case"iframe":case"object":L("load",l);break;case"video":case"audio":for(a=0;a<ve.length;a++)L(ve[a],l);break;case"image":L("error",l),L("load",l);break;case"details":L("toggle",l);break;case"embed":case"source":case"link":L("error",l),L("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(v in u)if(u.hasOwnProperty(v)&&(a=u[v],a!=null))switch(v){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,t));default:ul(l,t,v,a,u,null)}return;default:if($n(t)){for(g in u)u.hasOwnProperty(g)&&(a=u[g],a!==void 0&&Yc(l,t,g,a,u,void 0));return}}for(c in u)u.hasOwnProperty(c)&&(a=u[c],a!=null&&ul(l,t,c,a,u,null))}function Zy(l,t,u,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,f=null,c=null,i=null,v=null,g=null;for(m in u){var E=u[m];if(u.hasOwnProperty(m)&&E!=null)switch(m){case"checked":break;case"value":break;case"defaultValue":i=E;default:a.hasOwnProperty(m)||ul(l,t,m,null,a,E)}}for(var h in a){var m=a[h];if(E=u[h],a.hasOwnProperty(h)&&(m!=null||E!=null))switch(h){case"type":n=m;break;case"name":e=m;break;case"checked":v=m;break;case"defaultChecked":g=m;break;case"value":f=m;break;case"defaultValue":c=m;break;case"children":case"dangerouslySetInnerHTML":if(m!=null)throw Error(r(137,t));break;default:m!==E&&ul(l,t,h,m,a,E)}}wn(l,f,c,i,v,g,n,e);return;case"select":m=f=c=h=null;for(n in u)if(i=u[n],u.hasOwnProperty(n)&&i!=null)switch(n){case"value":break;case"multiple":m=i;default:a.hasOwnProperty(n)||ul(l,t,n,null,a,i)}for(e in a)if(n=a[e],i=u[e],a.hasOwnProperty(e)&&(n!=null||i!=null))switch(e){case"value":h=n;break;case"defaultValue":c=n;break;case"multiple":f=n;default:n!==i&&ul(l,t,e,n,a,i)}t=c,u=f,a=m,h!=null?Ju(l,!!u,h,!1):!!a!=!!u&&(t!=null?Ju(l,!!u,t,!0):Ju(l,!!u,u?[]:"",!1));return;case"textarea":m=h=null;for(c in u)if(e=u[c],u.hasOwnProperty(c)&&e!=null&&!a.hasOwnProperty(c))switch(c){case"value":break;case"children":break;default:ul(l,t,c,null,a,e)}for(f in a)if(e=a[f],n=u[f],a.hasOwnProperty(f)&&(e!=null||n!=null))switch(f){case"value":h=e;break;case"defaultValue":m=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(r(91));break;default:e!==n&&ul(l,t,f,e,a,n)}Ei(l,h,m);return;case"option":for(var M in u)if(h=u[M],u.hasOwnProperty(M)&&h!=null&&!a.hasOwnProperty(M))switch(M){case"selected":l.selected=!1;break;default:ul(l,t,M,null,a,h)}for(i in a)if(h=a[i],m=u[i],a.hasOwnProperty(i)&&h!==m&&(h!=null||m!=null))switch(i){case"selected":l.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:ul(l,t,i,h,a,m)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var B in u)h=u[B],u.hasOwnProperty(B)&&h!=null&&!a.hasOwnProperty(B)&&ul(l,t,B,null,a,h);for(v in a)if(h=a[v],m=u[v],a.hasOwnProperty(v)&&h!==m&&(h!=null||m!=null))switch(v){case"children":case"dangerouslySetInnerHTML":if(h!=null)throw Error(r(137,t));break;default:ul(l,t,v,h,a,m)}return;default:if($n(t)){for(var ml in u)h=u[ml],u.hasOwnProperty(ml)&&h!==void 0&&!a.hasOwnProperty(ml)&&Yc(l,t,ml,void 0,a,h);for(g in a)h=a[g],m=u[g],!a.hasOwnProperty(g)||h===m||h===void 0&&m===void 0||Yc(l,t,g,h,a,m);return}}for(var y in u)h=u[y],u.hasOwnProperty(y)&&h!=null&&!a.hasOwnProperty(y)&&ul(l,t,y,null,a,h);for(E in a)h=a[E],m=u[E],!a.hasOwnProperty(E)||h===m||h==null&&m==null||ul(l,t,E,h,a,m)}var Bc=null,Gc=null;function Dn(l){return l.nodeType===9?l:l.ownerDocument}function hd(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function rd(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function jc(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Xc=null;function xy(){var l=window.event;return l&&l.type==="popstate"?l===Xc?!1:(Xc=l,!0):(Xc=null,!1)}var md=typeof setTimeout=="function"?setTimeout:void 0,Vy=typeof clearTimeout=="function"?clearTimeout:void 0,gd=typeof Promise=="function"?Promise:void 0,Ly=typeof queueMicrotask=="function"?queueMicrotask:typeof gd<"u"?function(l){return gd.resolve(null).then(l).catch(Ky)}:md;function Ky(l){setTimeout(function(){throw l})}function Qc(l,t){var u=t,a=0;do{var e=u.nextSibling;if(l.removeChild(u),e&&e.nodeType===8)if(u=e.data,u==="/$"){if(a===0){l.removeChild(e),Ee(t);return}a--}else u!=="$"&&u!=="$?"&&u!=="$!"||a++;u=e}while(u);Ee(t)}function Cc(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var u=t;switch(t=t.nextSibling,u.nodeName){case"HTML":case"HEAD":case"BODY":Cc(u),Jn(u);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(u.rel.toLowerCase()==="stylesheet")continue}l.removeChild(u)}}function Jy(l,t,u,a){for(;l.nodeType===1;){var e=u;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(a){if(!l[Ua])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=gt(l.nextSibling),l===null)break}return null}function wy(l,t,u){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!u||(l=gt(l.nextSibling),l===null))return null;return l}function gt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return l}function Sd(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var u=l.data;if(u==="$"||u==="$!"||u==="$?"){if(t===0)return l;t--}else u==="/$"&&t++}l=l.previousSibling}return null}function bd(l,t,u){switch(t=Dn(u),l){case"html":if(l=t.documentElement,!l)throw Error(r(452));return l;case"head":if(l=t.head,!l)throw Error(r(453));return l;case"body":if(l=t.body,!l)throw Error(r(454));return l;default:throw Error(r(451))}}var yt=new Map,Ed=new Set;function Mn(l){return typeof l.getRootNode=="function"?l.getRootNode():l.ownerDocument}var Kt=O.d;O.d={f:Wy,r:$y,D:ky,C:Fy,L:Py,m:Iy,X:to,S:lo,M:uo};function Wy(){var l=Kt.f(),t=bn();return l||t}function $y(l){var t=Vu(l);t!==null&&t.tag===5&&t.type==="form"?ws(t):Kt.r(l)}var Ea=typeof document>"u"?null:document;function Td(l,t,u){var a=Ea;if(a&&typeof t=="string"&&t){var e=ut(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof u=="string"&&(e+='[crossorigin="'+u+'"]'),Ed.has(e)||(Ed.add(e),l={rel:l,crossOrigin:u,href:t},a.querySelector(e)===null&&(t=a.createElement("link"),pl(t,"link",l),Dl(t),a.head.appendChild(t)))}}function ky(l){Kt.D(l),Td("dns-prefetch",l,null)}function Fy(l,t){Kt.C(l,t),Td("preconnect",l,t)}function Py(l,t,u){Kt.L(l,t,u);var a=Ea;if(a&&l&&t){var e='link[rel="preload"][as="'+ut(t)+'"]';t==="image"&&u&&u.imageSrcSet?(e+='[imagesrcset="'+ut(u.imageSrcSet)+'"]',typeof u.imageSizes=="string"&&(e+='[imagesizes="'+ut(u.imageSizes)+'"]')):e+='[href="'+ut(l)+'"]';var n=e;switch(t){case"style":n=Ta(l);break;case"script":n=Aa(l)}yt.has(n)||(l=P({rel:"preload",href:t==="image"&&u&&u.imageSrcSet?void 0:l,as:t},u),yt.set(n,l),a.querySelector(e)!==null||t==="style"&&a.querySelector(oe(n))||t==="script"&&a.querySelector(he(n))||(t=a.createElement("link"),pl(t,"link",l),Dl(t),a.head.appendChild(t)))}}function Iy(l,t){Kt.m(l,t);var u=Ea;if(u&&l){var a=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+ut(a)+'"][href="'+ut(l)+'"]',n=e;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Aa(l)}if(!yt.has(n)&&(l=P({rel:"modulepreload",href:l},t),yt.set(n,l),u.querySelector(e)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(u.querySelector(he(n)))return}a=u.createElement("link"),pl(a,"link",l),Dl(a),u.head.appendChild(a)}}}function lo(l,t,u){Kt.S(l,t,u);var a=Ea;if(a&&l){var e=Lu(a).hoistableStyles,n=Ta(l);t=t||"default";var f=e.get(n);if(!f){var c={loading:0,preload:null};if(f=a.querySelector(oe(n)))c.loading=5;else{l=P({rel:"stylesheet",href:l,"data-precedence":t},u),(u=yt.get(n))&&Zc(l,u);var i=f=a.createElement("link");Dl(i),pl(i,"link",l),i._p=new Promise(function(v,g){i.onload=v,i.onerror=g}),i.addEventListener("load",function(){c.loading|=1}),i.addEventListener("error",function(){c.loading|=2}),c.loading|=4,Un(f,t,a)}f={type:"stylesheet",instance:f,count:1,state:c},e.set(n,f)}}}function to(l,t){Kt.X(l,t);var u=Ea;if(u&&l){var a=Lu(u).hoistableScripts,e=Aa(l),n=a.get(e);n||(n=u.querySelector(he(e)),n||(l=P({src:l,async:!0},t),(t=yt.get(e))&&xc(l,t),n=u.createElement("script"),Dl(n),pl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function uo(l,t){Kt.M(l,t);var u=Ea;if(u&&l){var a=Lu(u).hoistableScripts,e=Aa(l),n=a.get(e);n||(n=u.querySelector(he(e)),n||(l=P({src:l,async:!0,type:"module"},t),(t=yt.get(e))&&xc(l,t),n=u.createElement("script"),Dl(n),pl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function Ad(l,t,u,a){var e=(e=$t.current)?Mn(e):null;if(!e)throw Error(r(446));switch(l){case"meta":case"title":return null;case"style":return typeof u.precedence=="string"&&typeof u.href=="string"?(t=Ta(u.href),u=Lu(e).hoistableStyles,a=u.get(t),a||(a={type:"style",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(u.rel==="stylesheet"&&typeof u.href=="string"&&typeof u.precedence=="string"){l=Ta(u.href);var n=Lu(e).hoistableStyles,f=n.get(l);if(f||(e=e.ownerDocument||e,f={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,f),(n=e.querySelector(oe(l)))&&!n._p&&(f.instance=n,f.state.loading=5),yt.has(l)||(u={rel:"preload",as:"style",href:u.href,crossOrigin:u.crossOrigin,integrity:u.integrity,media:u.media,hrefLang:u.hrefLang,referrerPolicy:u.referrerPolicy},yt.set(l,u),n||ao(e,l,u,f.state))),t&&a===null)throw Error(r(528,""));return f}if(t&&a!==null)throw Error(r(529,""));return null;case"script":return t=u.async,u=u.src,typeof u=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Aa(u),u=Lu(e).hoistableScripts,a=u.get(t),a||(a={type:"script",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,l))}}function Ta(l){return'href="'+ut(l)+'"'}function oe(l){return'link[rel="stylesheet"]['+l+"]"}function zd(l){return P({},l,{"data-precedence":l.precedence,precedence:null})}function ao(l,t,u,a){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=l.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),pl(t,"link",u),Dl(t),l.head.appendChild(t))}function Aa(l){return'[src="'+ut(l)+'"]'}function he(l){return"script[async]"+l}function Od(l,t,u){if(t.count++,t.instance===null)switch(t.type){case"style":var a=l.querySelector('style[data-href~="'+ut(u.href)+'"]');if(a)return t.instance=a,Dl(a),a;var e=P({},u,{"data-href":u.href,"data-precedence":u.precedence,href:null,precedence:null});return a=(l.ownerDocument||l).createElement("style"),Dl(a),pl(a,"style",e),Un(a,u.precedence,l),t.instance=a;case"stylesheet":e=Ta(u.href);var n=l.querySelector(oe(e));if(n)return t.state.loading|=4,t.instance=n,Dl(n),n;a=zd(u),(e=yt.get(e))&&Zc(a,e),n=(l.ownerDocument||l).createElement("link"),Dl(n);var f=n;return f._p=new Promise(function(c,i){f.onload=c,f.onerror=i}),pl(n,"link",a),t.state.loading|=4,Un(n,u.precedence,l),t.instance=n;case"script":return n=Aa(u.src),(e=l.querySelector(he(n)))?(t.instance=e,Dl(e),e):(a=u,(e=yt.get(n))&&(a=P({},u),xc(a,e)),l=l.ownerDocument||l,e=l.createElement("script"),Dl(e),pl(e,"link",a),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(r(443,t.type))}else t.type==="stylesheet"&&!(t.state.loading&4)&&(a=t.instance,t.state.loading|=4,Un(a,u.precedence,l));return t.instance}function Un(l,t,u){for(var a=u.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=a.length?a[a.length-1]:null,n=e,f=0;f<a.length;f++){var c=a[f];if(c.dataset.precedence===t)n=c;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=u.nodeType===9?u.head:u,t.insertBefore(l,t.firstChild))}function Zc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function xc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Rn=null;function _d(l,t,u){if(Rn===null){var a=new Map,e=Rn=new Map;e.set(u,a)}else e=Rn,a=e.get(u),a||(a=new Map,e.set(u,a));if(a.has(l))return a;for(a.set(l,null),u=u.getElementsByTagName(l),e=0;e<u.length;e++){var n=u[e];if(!(n[Ua]||n[ql]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var f=n.getAttribute(t)||"";f=l+f;var c=a.get(f);c?c.push(n):a.set(f,[n])}}return a}function Dd(l,t,u){l=l.ownerDocument||l,l.head.insertBefore(u,t==="title"?l.querySelector("head > title"):null)}function eo(l,t,u){if(u===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Md(l){return!(l.type==="stylesheet"&&!(l.state.loading&3))}var re=null;function no(){}function fo(l,t,u){if(re===null)throw Error(r(475));var a=re;if(t.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&!(t.state.loading&4)){if(t.instance===null){var e=Ta(u.href),n=l.querySelector(oe(e));if(n){l=n._p,l!==null&&typeof l=="object"&&typeof l.then=="function"&&(a.count++,a=Hn.bind(a),l.then(a,a)),t.state.loading|=4,t.instance=n,Dl(n);return}n=l.ownerDocument||l,u=zd(u),(e=yt.get(e))&&Zc(u,e),n=n.createElement("link"),Dl(n);var f=n;f._p=new Promise(function(c,i){f.onload=c,f.onerror=i}),pl(n,"link",u),t.instance=n}a.stylesheets===null&&(a.stylesheets=new Map),a.stylesheets.set(t,l),(l=t.state.preload)&&!(t.state.loading&3)&&(a.count++,t=Hn.bind(a),l.addEventListener("load",t),l.addEventListener("error",t))}}function co(){if(re===null)throw Error(r(475));var l=re;return l.stylesheets&&l.count===0&&Vc(l,l.stylesheets),0<l.count?function(t){var u=setTimeout(function(){if(l.stylesheets&&Vc(l,l.stylesheets),l.unsuspend){var a=l.unsuspend;l.unsuspend=null,a()}},6e4);return l.unsuspend=t,function(){l.unsuspend=null,clearTimeout(u)}}:null}function Hn(){if(this.count--,this.count===0){if(this.stylesheets)Vc(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Nn=null;function Vc(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Nn=new Map,t.forEach(io,l),Nn=null,Hn.call(l))}function io(l,t){if(!(t.state.loading&4)){var u=Nn.get(l);if(u)var a=u.get(null);else{u=new Map,Nn.set(l,u);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var f=e[n];(f.nodeName==="LINK"||f.getAttribute("media")!=="not all")&&(u.set(f.dataset.precedence,f),a=f)}a&&u.set(null,a)}e=t.instance,f=e.getAttribute("data-precedence"),n=u.get(f)||a,n===a&&u.set(null,e),u.set(f,e),this.count++,a=Hn.bind(this),e.addEventListener("load",a),e.addEventListener("error",a),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var me={$$typeof:cl,Provider:null,Consumer:null,_currentValue:K,_currentValue2:K,_threadCount:0};function so(l,t,u,a,e,n,f,c){this.tag=1,this.containerInfo=l,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ln(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.finishedLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ln(0),this.hiddenUpdates=Ln(null),this.identifierPrefix=a,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=f,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=c,this.incompleteTransitions=new Map}function Ud(l,t,u,a,e,n,f,c,i,v,g,E){return l=new so(l,t,u,f,c,i,v,E),t=1,n===!0&&(t|=24),n=dt(3,null,null,t),l.current=n,n.stateNode=l,t=Tf(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:a,isDehydrated:u,cache:t},tc(n),l}function Rd(l){return l?(l=la,l):la}function Hd(l,t,u,a,e,n){e=Rd(e),a.context===null?a.context=e:a.pendingContext=e,a=fu(t),a.payload={element:u},n=n===void 0?null:n,n!==null&&(a.callback=n),u=cu(l,a,t),u!==null&&(Ql(u,l,t),Ia(u,l,t))}function Nd(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var u=l.retryLane;l.retryLane=u!==0&&u<t?u:t}}function Lc(l,t){Nd(l,t),(l=l.alternate)&&Nd(l,t)}function pd(l){if(l.tag===13){var t=It(l,67108864);t!==null&&Ql(t,l,67108864),Lc(l,67108864)}}var pn=!0;function vo(l,t,u,a){var e=N.T;N.T=null;var n=O.p;try{O.p=2,Kc(l,t,u,a)}finally{O.p=n,N.T=e}}function yo(l,t,u,a){var e=N.T;N.T=null;var n=O.p;try{O.p=8,Kc(l,t,u,a)}finally{O.p=n,N.T=e}}function Kc(l,t,u,a){if(pn){var e=Jc(a);if(e===null)qc(l,t,a,qn,u),Yd(l,a);else if(ho(e,l,t,u,a))a.stopPropagation();else if(Yd(l,a),t&4&&-1<oo.indexOf(l)){for(;e!==null;){var n=Vu(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var f=bu(n.pendingLanes);if(f!==0){var c=n;for(c.pendingLanes|=2,c.entangledLanes|=2;f;){var i=1<<31-wl(f);c.entanglements[1]|=i,f&=~i}_t(n),!(ol&6)&&(mn=Et()+500,de(0))}}break;case 13:c=It(n,2),c!==null&&Ql(c,n,2),bn(),Lc(n,2)}if(n=Jc(a),n===null&&qc(l,t,a,qn,u),n===e)break;e=n}e!==null&&a.stopPropagation()}else qc(l,t,a,null,u)}}function Jc(l){return l=Fn(l),wc(l)}var qn=null;function wc(l){if(qn=null,l=Eu(l),l!==null){var t=Y(l);if(t===null)l=null;else{var u=t.tag;if(u===13){if(l=il(t),l!==null)return l;l=null}else if(u===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return qn=l,null}function qd(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Fd()){case ai:return 2;case ei:return 8;case Me:case Pd:return 32;case ni:return 268435456;default:return 32}default:return 32}}var Wc=!1,hu=null,ru=null,mu=null,ge=new Map,Se=new Map,gu=[],oo="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function Yd(l,t){switch(l){case"focusin":case"focusout":hu=null;break;case"dragenter":case"dragleave":ru=null;break;case"mouseover":case"mouseout":mu=null;break;case"pointerover":case"pointerout":ge.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Se.delete(t.pointerId)}}function be(l,t,u,a,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:u,eventSystemFlags:a,nativeEvent:n,targetContainers:[e]},t!==null&&(t=Vu(t),t!==null&&pd(t)),l):(l.eventSystemFlags|=a,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function ho(l,t,u,a,e){switch(t){case"focusin":return hu=be(hu,l,t,u,a,e),!0;case"dragenter":return ru=be(ru,l,t,u,a,e),!0;case"mouseover":return mu=be(mu,l,t,u,a,e),!0;case"pointerover":var n=e.pointerId;return ge.set(n,be(ge.get(n)||null,l,t,u,a,e)),!0;case"gotpointercapture":return n=e.pointerId,Se.set(n,be(Se.get(n)||null,l,t,u,a,e)),!0}return!1}function Bd(l){var t=Eu(l.target);if(t!==null){var u=Y(t);if(u!==null){if(t=u.tag,t===13){if(t=il(u),t!==null){l.blockedOn=t,cv(l.priority,function(){if(u.tag===13){var a=Pl(),e=It(u,a);e!==null&&Ql(e,u,a),Lc(u,a)}});return}}else if(t===3&&u.stateNode.current.memoizedState.isDehydrated){l.blockedOn=u.tag===3?u.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Yn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var u=Jc(l.nativeEvent);if(u===null){u=l.nativeEvent;var a=new u.constructor(u.type,u);kn=a,u.target.dispatchEvent(a),kn=null}else return t=Vu(u),t!==null&&pd(t),l.blockedOn=u,!1;t.shift()}return!0}function Gd(l,t,u){Yn(l)&&u.delete(t)}function ro(){Wc=!1,hu!==null&&Yn(hu)&&(hu=null),ru!==null&&Yn(ru)&&(ru=null),mu!==null&&Yn(mu)&&(mu=null),ge.forEach(Gd),Se.forEach(Gd)}function Bn(l,t){l.blockedOn===t&&(l.blockedOn=null,Wc||(Wc=!0,A.unstable_scheduleCallback(A.unstable_NormalPriority,ro)))}var Gn=null;function jd(l){Gn!==l&&(Gn=l,A.unstable_scheduleCallback(A.unstable_NormalPriority,function(){Gn===l&&(Gn=null);for(var t=0;t<l.length;t+=3){var u=l[t],a=l[t+1],e=l[t+2];if(typeof a!="function"){if(wc(a||u)===null)continue;break}var n=Vu(u);n!==null&&(l.splice(t,3),t-=3,jf(n,{pending:!0,data:e,method:u.method,action:a},a,e))}}))}function Ee(l){function t(i){return Bn(i,l)}hu!==null&&Bn(hu,l),ru!==null&&Bn(ru,l),mu!==null&&Bn(mu,l),ge.forEach(t),Se.forEach(t);for(var u=0;u<gu.length;u++){var a=gu[u];a.blockedOn===l&&(a.blockedOn=null)}for(;0<gu.length&&(u=gu[0],u.blockedOn===null);)Bd(u),u.blockedOn===null&&gu.shift();if(u=(l.ownerDocument||l).$$reactFormReplay,u!=null)for(a=0;a<u.length;a+=3){var e=u[a],n=u[a+1],f=e[xl]||null;if(typeof n=="function")f||jd(u);else if(f){var c=null;if(n&&n.hasAttribute("formAction")){if(e=n,f=n[xl]||null)c=f.formAction;else if(wc(e)!==null)continue}else c=f.action;typeof c=="function"?u[a+1]=c:(u.splice(a,3),a-=3),jd(u)}}}function $c(l){this._internalRoot=l}jn.prototype.render=$c.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(r(409));var u=t.current,a=Pl();Hd(u,a,l,t,null,null)},jn.prototype.unmount=$c.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;l.tag===0&&ga(),Hd(l.current,2,null,l,null,null),bn(),t[xu]=null}};function jn(l){this._internalRoot=l}jn.prototype.unstable_scheduleHydration=function(l){if(l){var t=vi();l={blockedOn:null,target:l,priority:t};for(var u=0;u<gu.length&&t!==0&&t<gu[u].priority;u++);gu.splice(u,0,l),u===0&&Bd(l)}};var Xd=w.version;if(Xd!=="19.0.0")throw Error(r(527,Xd,"19.0.0"));O.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(r(188)):(l=Object.keys(l).join(","),Error(r(268,l)));return l=T(t),l=l!==null?p(l):null,l=l===null?null:l.stateNode,l};var mo={bundleType:0,version:"19.0.0",rendererPackageName:"react-dom",currentDispatcherRef:N,findFiberByHostInstance:Eu,reconcilerVersion:"19.0.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Xn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Xn.isDisabled&&Xn.supportsFiber)try{_a=Xn.inject(mo),Jl=Xn}catch{}}return Ae.createRoot=function(l,t){if(!X(l))throw Error(r(299));var u=!1,a="",e=t0,n=u0,f=a0,c=null;return t!=null&&(t.unstable_strictMode===!0&&(u=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(f=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(c=t.unstable_transitionCallbacks)),t=Ud(l,1,!1,null,null,u,a,e,n,f,c,null),l[xu]=t.current,pc(l.nodeType===8?l.parentNode:l),new $c(t)},Ae.hydrateRoot=function(l,t,u){if(!X(l))throw Error(r(299));var a=!1,e="",n=t0,f=u0,c=a0,i=null,v=null;return u!=null&&(u.unstable_strictMode===!0&&(a=!0),u.identifierPrefix!==void 0&&(e=u.identifierPrefix),u.onUncaughtError!==void 0&&(n=u.onUncaughtError),u.onCaughtError!==void 0&&(f=u.onCaughtError),u.onRecoverableError!==void 0&&(c=u.onRecoverableError),u.unstable_transitionCallbacks!==void 0&&(i=u.unstable_transitionCallbacks),u.formState!==void 0&&(v=u.formState)),t=Ud(l,1,!0,t,u??null,a,e,n,f,c,i,v),t.context=Rd(null),u=t.current,a=Pl(),e=fu(a),e.callback=null,cu(u,e,a),t.current.lanes=a,Ma(t,a),_t(t),l[xu]=t.current,pc(l),new jn(t)},Ae.version="19.0.0",Ae}var Wd;function Do(){if(Wd)return Pc.exports;Wd=1;function A(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(A)}catch(w){console.error(w)}}return A(),Pc.exports=_o(),Pc.exports}var Mo=Do();const ze="http://127.0.0.1:8000/api",Qn={async addTorrent(A){const w=await fetch(`${ze}/torrent/add`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({magnet_link:A})});if(!w.ok){const V=await w.json();throw new Error(V.detail||"Failed to add torrent")}return w.json()},async listTorrents(){const A=await fetch(`${ze}/torrent/list`);if(!A.ok)throw new Error("Failed to fetch torrents");return A.json()},async removeTorrent(A,w=!1){if(!(await fetch(`${ze}/torrent/${A}?delete_files=${w}`,{method:"DELETE"})).ok)throw new Error("Failed to remove torrent")},async getDownloadsPath(){const A=await fetch(`${ze}/downloads/path`);if(!A.ok)throw new Error("Failed to get downloads path");return(await A.json()).path},async openDownloadsFolder(){const A=await fetch(`${ze}/downloads/open`,{method:"POST"});if(!A.ok){const w=await A.json();throw new Error(w.detail||"Failed to open downloads folder")}}};function Uo(){const[A,w]=za.useState(""),[V,r]=za.useState([]),[X,I]=za.useState(!1),[fl,al]=za.useState(null);za.useEffect(()=>{const q=async()=>{try{const _l=await Qn.listTorrents();r(_l),al(null)}catch(_l){al("Failed to fetch torrents"),console.error("Error fetching torrents:",_l)}};q();const cl=setInterval(q,1e3);return()=>clearInterval(cl)},[]);const D=async()=>{if(A.trim()){I(!0),al(null);try{await Qn.addTorrent(A),w("")}catch(q){al("Failed to add torrent"),console.error("Error adding torrent:",q)}finally{I(!1)}}},b=async q=>{try{await Qn.removeTorrent(q),r(V.filter(cl=>cl.id!==q)),al(null)}catch(cl){al("Failed to remove torrent"),console.error("Error removing torrent:",cl)}},W=async()=>{try{await Qn.openDownloadsFolder(),al(null)}catch(q){al("Failed to open downloads folder"),console.error("Error opening downloads folder:",q)}},el=q=>q>1024?`${(q/1024).toFixed(2)} MB/s`:`${q.toFixed(2)} KB/s`;return Sl.jsxs("div",{className:"container",children:[Sl.jsxs("header",{children:[Sl.jsx("h1",{children:"Torrent Downloader"}),Sl.jsx("button",{onClick:W,children:"Open Downloads"})]}),fl&&Sl.jsx("div",{className:"error-message",children:fl}),Sl.jsxs("div",{className:"input-section",children:[Sl.jsx("input",{type:"text",value:A,onChange:q=>w(q.target.value),placeholder:"Enter magnet link...",disabled:X}),Sl.jsx("button",{onClick:D,disabled:X||!A.trim(),children:"Add Torrent"})]}),Sl.jsx("div",{className:"torrents-list",children:V.map(q=>Sl.jsxs("div",{className:"torrent-item",children:[Sl.jsxs("div",{className:"torrent-info",children:[Sl.jsxs("div",{className:"torrent-header",children:[Sl.jsx("h3",{children:q.name}),Sl.jsx("button",{onClick:()=>b(q.id),className:"remove-button",children:"Remove"})]}),Sl.jsxs("p",{children:["Status: ",q.state]}),Sl.jsxs("p",{children:["Speed: ",el(q.download_speed)]}),Sl.jsxs("p",{children:["Progress: ",q.progress.toFixed(1),"%"]})]}),Sl.jsx("div",{className:"progress-bar",children:Sl.jsx("div",{className:"progress",style:{width:`${q.progress}%`}})})]},q.id))})]})}Mo.createRoot(document.getElementById("root")).render(Sl.jsx(za.StrictMode,{children:Sl.jsx(Uo,{})}));
